@@ -34,6 +34,9 @@
 /* Define this if you want some extra (possibly verbose) run time self tests */
 #undef PIKE_EXTRA_DEBUG
 
+/* Define this to enable some experimental code. */
+#undef PIKE_EXPERIMENTAL
+
 /* Define to make Pike do a full cleanup at exit to detect leaks. */
 #undef DO_PIKE_CLEANUP
 
@@ -91,6 +94,9 @@
 /* Enable internal profiling */
 #undef INTERNAL_PROFILING
 
+/* Enable machine code stack frames */
+#undef MACHINE_CODE_STACK_FRAMES
+
 /* If possible, the expansion for a "#define short" to avoid that bison
  * uses short everywhere internally. */
 #undef BISON_SHORT_EXPANSION
@@ -648,4 +654,16 @@ struct mallinfo {
 
 #endif
 
+#ifdef PIKE_DEBUG
+#ifndef YYDEBUG
+/* May also be set above. */
+#define YYDEBUG 1
+#endif /* YYDEBUG */
+#endif
+
+#ifdef PIKE_EXPERIMENTAL
+#define MACHINE_CODE_STACK_FRAMES
+#define PIKE_AMD64_VALIDATE_RSP
+#endif
+
 #endif /* MACHINE_H */
