@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: cfc61da8df14f5f16e25adc458fde16014fbb357 $
 */
 
     {
@@ -11,21 +10,10 @@
       struct pike_frame *new_frame;
       struct identifier *function;
 
-#if 0
-      /* This kind of fault tolerance is braindamaged. /mast */
-      if(fun<0)
-      {
-	pop_n_elems(Pike_sp-save_sp);
-	push_undefined();
-	return 0;
-      }
-#else
 #ifdef PIKE_DEBUG
       if (fun < 0)
 	Pike_fatal ("Invalid function offset: %d.\n", fun);
 #endif
-#endif
-
       check_stack(256);
       check_mark_stack(256);
 
@@ -147,25 +135,19 @@
       new_frame->expendible = new_frame->locals = Pike_sp - args;
       new_frame->args = args;
       new_frame->pc = 0;
-#ifdef SCOPE
       new_frame->scope=scope;
 #ifdef PIKE_DEBUG
-      if(new_frame->fun == scope->fun)
+      if(scope && new_frame->fun == scope->fun)
       {
 	Pike_fatal("Que? A function cannot be parented by itself!\n");
       }
-#endif
-#else
-      new_frame->scope=0;
 #endif
       new_frame->save_sp=save_sp;
-      
+
       add_ref(new_frame->current_object);
       add_ref(new_frame->current_program);
-#ifdef SCOPE
       if(new_frame->scope) add_ref(new_frame->scope);
-#endif
-#ifdef PIKE_DEBUG      
+#ifdef PIKE_DEBUG
       if (Pike_fp) {
 
 	if (new_frame->locals < Pike_fp->locals) {
@@ -178,7 +160,7 @@
 	  size_t i;
 	  struct svalue *l = Pike_fp->locals;
 	  for (i = 0; l + i < Pike_sp; i++)
-	    if (l[i].type != PIKE_T_FREE)
+	    if (TYPEOF(l[i]) != PIKE_T_FREE)
 	      debug_check_svalue (l + i);
 	}
       }
@@ -200,6 +182,22 @@
 	  my_strcat(function->name->str);
 	do_trace_call(args, &save_buf);
       }
+      if (PIKE_FN_START_ENABLED()) {
+	/* DTrace enter probe
+	   arg0: function name
+	   arg1: object
+	*/
+	dynamic_buffer save_buf;
+	dynbuf_string obj_name;
+	struct svalue obj_sval;
+	SET_SVAL(obj_sval, T_OBJECT, 0, object, o);
+	init_buf(&save_buf);
+	safe_describe_svalue(&obj_sval, 0, NULL);
+	obj_name = complex_free_buf(&save_buf);
+	PIKE_FN_START(function->name->size_shift == 0 ?
+		      function->name->str : "[widestring fn name]",
+		      obj_name.str);
+      }
 
 #ifdef PROFILING
       function->num_calls++;
@@ -213,7 +211,7 @@
       }
       
       switch(function->identifier_flags & (IDENTIFIER_TYPE_MASK|IDENTIFIER_ALIAS))
-      {       
+      {
       case IDENTIFIER_C_FUNCTION:
 	debug_malloc_touch(Pike_fp);
 	Pike_fp->num_args=args;
@@ -226,9 +224,9 @@
       case IDENTIFIER_CONSTANT:
       {
 	struct svalue *s=&(Pike_fp->context->prog->
-			   constants[function->func.offset].sval);
+			   constants[function->func.const_info.offset].sval);
 	debug_malloc_touch(Pike_fp);
-	if(s->type == T_PROGRAM)
+	if(TYPEOF(*s) == T_PROGRAM)
 	{
 	  struct object *tmp;
 	  FAST_CHECK_THREADS_ON_CALL();
@@ -254,7 +252,7 @@
 	{
 	  /* Create an extra svalue for tail recursion style call */
 	  Pike_sp++;
-	  MEMMOVE(Pike_sp-args,Pike_sp-args-1,sizeof(struct svalue)*args);
+	  memmove(Pike_sp-args,Pike_sp-args-1,sizeof(struct svalue)*args);
 #ifdef DEBUG_MALLOC
 	  if (args) {
 	    int i;
@@ -282,6 +280,10 @@
 	  pop_n_elems(Pike_sp-save_sp-args);
 	}
 	arg1=(void *)(Pike_sp-args-1);
+	if (PIKE_FN_POPFRAME_ENABLED()) {
+	  /* DTrace adjust frame depth */
+	  PIKE_FN_POPFRAME();
+	}
 	goto apply_svalue;
       }
 
@@ -295,56 +297,13 @@
 #ifdef PIKE_DEBUG
 	if (Pike_in_gc > GC_PASS_PREPARE && Pike_in_gc < GC_PASS_FREE)
 	  Pike_fatal("Pike code called within gc.\n");
+    new_frame->num_args = 0;
+    new_frame->num_locals = 0;
 #endif
 
 	debug_malloc_touch(Pike_fp);
 	pc=new_frame->context->prog->program + function->func.offset;
 
-	/*
-	 * FIXME: The following stack stuff could probably
-	 *        be moved to an opcode.
-	 */
-
-	num_locals = READ_INCR_BYTE(pc);
-
-	if(function->identifier_flags & IDENTIFIER_SCOPE_USED)
-	  new_frame->expendible+=num_locals;
-
-	num_args = READ_INCR_BYTE(pc);
-
-#ifdef PIKE_DEBUG
-	if(num_locals < num_args)
-	  Pike_fatal("Wrong number of arguments or locals in function def.\n"
-		"num_locals: %d < num_args: %d\n",
-		num_locals, num_args);
-#endif
-
-	
-	if(function->identifier_flags & IDENTIFIER_VARARGS)
-	{
-	  /* adjust arguments on stack */
-	  if(args < num_args) /* push zeros */
-	  {
-	    push_undefines(num_args-args);
-	    f_aggregate(0);
-	  }else{
-	    f_aggregate(args - num_args); /* make array */
-	  }
-	  args = num_args+1;
-	}else{
-	  /* adjust arguments on stack */
-	  if(args < num_args) /* push zeros */
-	    push_undefines(num_args-args);
-	  else
-	    pop_n_elems(args - num_args);
-	  args=num_args;
-	}
-
-	if(num_locals > args)
-	  push_zeroes(num_locals-args);
-
-	new_frame->num_locals=num_locals;
-	new_frame->num_args=num_args;
 	new_frame->save_mark_sp=new_frame->mark_sp_base=Pike_mark_sp;
 	new_frame->pc = pc
 #ifdef ENTRY_PROLOGUE_SIZE
@@ -352,7 +311,7 @@
 #endif /* ENTRY_PROLOGUE_SIZE */
 	  ;
 
-	return 1;
+	return new_frame->pc;
       }
 
       default:
@@ -368,19 +327,15 @@
 	    p = (o = loc.o)->prog;
 	    function = ID_FROM_INT(p, fun);
 	  } while (IDENTIFIER_IS_ALIAS(function->identifier_flags));
+	  if (PIKE_FN_POPFRAME_ENABLED()) {
+	    /* DTrace adjust frame depth */
+	    PIKE_FN_POPFRAME();
+	  }
 	  goto apply_low;
 	}
 #ifdef PIKE_DEBUG
 	Pike_fatal("Unknown identifier type.\n");
 #endif
       }
-
-#if 0
-#ifdef PIKE_DEBUG
-      if(Pike_fp!=new_frame)
-	Pike_fatal("Frame stack out of whack!\n");
-#endif
-#endif
-      
       POP_PIKE_FRAME();
     }
