@@ -361,6 +361,7 @@ PMOD_EXPORT void convert_svalue_to_bignum(struct svalue *s);
 
 #ifdef INT64
 PMOD_EXPORT extern void (*push_int64)(INT64 i);
+PMOD_EXPORT extern void (*ulongest_to_svalue_no_free)(struct svalue *sv, UINT64 i);
 
 /* Returns nonzero iff conversion is successful. */
 PMOD_EXPORT extern int (*int64_from_bignum) (INT64 *i, struct object *bignum);
@@ -381,6 +382,7 @@ PMOD_EXPORT extern void (*push_bignum)(MP_INT *);
 PMOD_EXPORT void hook_in_gmp_funcs (
 #ifdef INT64
   void (*push_int64_val)(INT64),
+  void (*ulongest_to_svalue_no_free_val)(struct svalue *, UINT64),
   int (*int64_from_bignum_val) (INT64 *, struct object *),
   void (*reduce_stack_top_bignum_val) (void),
 #endif
