@@ -1,6 +1,6 @@
 /*
  * Created by make_ci.pike
- * on Sun Jan 30 17:50:25 2022
+ * on Sat Feb  8 18:00:35 2025
  *
  * Table used for looking up the case of
  * Unicode characters.
@@ -49,7 +49,7 @@
 { 0x000197, CIM_UPPERDELTA, 0x00d1, },
 { 0x000198, CIM_CASEBIT, 0x0001, },
 { 0x00019a, CIM_LOWERDELTA, -0x00a3, },
-{ 0x00019b, CIM_NONE, 0x0000, },
+{ 0x00019b, CIM_LONGLOWERDELTA, -0x2641, },
 { 0x00019c, CIM_UPPERDELTA, 0x00d3, },
 { 0x00019d, CIM_UPPERDELTA, 0x00d5, },
 { 0x00019e, CIM_LOWERDELTA, -0x0082, },
@@ -116,13 +116,13 @@
 { 0x000261, CIM_LONGLOWERDELTA, -0x254b, },
 { 0x000262, CIM_NONE, 0x0000, },
 { 0x000263, CIM_LOWERDELTA, 0x00cf, },
-{ 0x000264, CIM_NONE, 0x0000, },
+{ 0x000264, CIM_LONGLOWERDELTA, -0x2567, },
 { 0x000265, CIM_LONGLOWERDELTA, -0x2528, },
 { 0x000266, CIM_LONGLOWERDELTA, -0x2544, },
 { 0x000267, CIM_NONE, 0x0000, },
 { 0x000268, CIM_LOWERDELTA, 0x00d1, },
 { 0x000269, CIM_LOWERDELTA, 0x00d3, },
-{ 0x00026a, CIM_NONE, 0x0000, },
+{ 0x00026a, CIM_LONGLOWERDELTA, -0x2544, },
 { 0x00026b, CIM_LOWERDELTA, -0x29f7, },
 { 0x00026c, CIM_LONGLOWERDELTA, -0x2541, },
 { 0x00026d, CIM_NONE, 0x0000, },
@@ -137,6 +137,7 @@
 { 0x00027e, CIM_NONE, 0x0000, },
 { 0x000280, CIM_LOWERDELTA, 0x00da, },
 { 0x000281, CIM_NONE, 0x0000, },
+{ 0x000282, CIM_LONGLOWERDELTA, -0x2543, },
 { 0x000283, CIM_LOWERDELTA, 0x00da, },
 { 0x000284, CIM_NONE, 0x0000, },
 { 0x000287, CIM_LONGLOWERDELTA, -0x252a, },
@@ -225,15 +226,35 @@
 { 0x0010c8, CIM_NONE, 0x0000, },
 { 0x0010cd, CIM_UPPERDELTA, 0x1c60, },
 { 0x0010ce, CIM_NONE, 0x0000, },
+{ 0x0010d0, CIM_LOWERDELTA, 0x0000, },
+{ 0x0010fb, CIM_NONE, 0x0000, },
+{ 0x0010fd, CIM_LOWERDELTA, 0x0000, },
+{ 0x001100, CIM_NONE, 0x0000, },
 { 0x0013a0, CIM_LONGUPPERDELTA, 0x17d1, },
 { 0x0013f0, CIM_CASEBIT, 0x0008, },
 { 0x0013f6, CIM_NONE, 0x0000, },
 { 0x0013f8, CIM_CASEBIT, 0x0008, },
 { 0x0013fe, CIM_NONE, 0x0000, },
+{ 0x001c80, CIM_LOWERDELTA, 0x186e, },
+{ 0x001c81, CIM_LOWERDELTA, 0x186d, },
+{ 0x001c82, CIM_LOWERDELTA, 0x1864, },
+{ 0x001c83, CIM_LOWERDELTA, 0x1862, },
+{ 0x001c85, CIM_LOWERDELTA, 0x1863, },
+{ 0x001c86, CIM_LOWERDELTA, 0x185c, },
+{ 0x001c87, CIM_LOWERDELTA, 0x1825, },
+{ 0x001c88, CIM_LONGLOWERDELTA, -0x09c2, },
+{ 0x001c89, CIM_CASEBITOFF, 0x0001, },
+{ 0x001c8b, CIM_NONE, 0x0000, },
+{ 0x001c90, CIM_UPPERDELTA, -0x0bc0, },
+{ 0x001cbb, CIM_NONE, 0x0000, },
+{ 0x001cbd, CIM_UPPERDELTA, -0x0bc0, },
+{ 0x001cc0, CIM_NONE, 0x0000, },
 { 0x001d79, CIM_LONGLOWERDELTA, -0x0a04, },
 { 0x001d7a, CIM_NONE, 0x0000, },
 { 0x001d7d, CIM_LOWERDELTA, -0x0ee6, },
 { 0x001d7e, CIM_NONE, 0x0000, },
+{ 0x001d8e, CIM_LONGLOWERDELTA, -0x0a38, },
+{ 0x001d8f, CIM_NONE, 0x0000, },
 { 0x001e00, CIM_CASEBIT, 0x0001, },
 { 0x001e96, CIM_NONE, 0x0000, },
 { 0x001e9b, CIM_LOWERDELTA, 0x003b, },
@@ -336,9 +357,7 @@
 { 0x0024d0, CIM_LOWERDELTA, 0x001a, },
 { 0x0024ea, CIM_NONE, 0x0000, },
 { 0x002c00, CIM_UPPERDELTA, 0x0030, },
-{ 0x002c2f, CIM_NONE, 0x0000, },
 { 0x002c30, CIM_LOWERDELTA, 0x0030, },
-{ 0x002c5f, CIM_NONE, 0x0000, },
 { 0x002c60, CIM_CASEBIT, 0x0001, },
 { 0x002c62, CIM_UPPERDELTA, -0x29f7, },
 { 0x002c63, CIM_UPPERDELTA, -0x0ee6, },
@@ -384,19 +403,34 @@
 { 0x00a78d, CIM_LONGUPPERDELTA, -0x2528, },
 { 0x00a78e, CIM_NONE, 0x0000, },
 { 0x00a790, CIM_CASEBIT, 0x0001, },
-{ 0x00a794, CIM_NONE, 0x0000, },
+{ 0x00a794, CIM_LOWERDELTA, -0x0030, },
+{ 0x00a795, CIM_NONE, 0x0000, },
 { 0x00a796, CIM_CASEBIT, 0x0001, },
 { 0x00a7aa, CIM_LONGUPPERDELTA, -0x2544, },
 { 0x00a7ab, CIM_LONGUPPERDELTA, -0x254f, },
 { 0x00a7ac, CIM_LONGUPPERDELTA, -0x254b, },
 { 0x00a7ad, CIM_LONGUPPERDELTA, -0x2541, },
-{ 0x00a7ae, CIM_NONE, 0x0000, },
+{ 0x00a7ae, CIM_LONGUPPERDELTA, -0x2544, },
+{ 0x00a7af, CIM_NONE, 0x0000, },
 { 0x00a7b0, CIM_LONGUPPERDELTA, -0x2512, },
 { 0x00a7b1, CIM_LONGUPPERDELTA, -0x252a, },
 { 0x00a7b2, CIM_LONGUPPERDELTA, -0x2515, },
 { 0x00a7b3, CIM_UPPERDELTA, 0x03a0, },
 { 0x00a7b4, CIM_CASEBIT, 0x0001, },
-{ 0x00a7b8, CIM_NONE, 0x0000, },
+{ 0x00a7c4, CIM_UPPERDELTA, -0x0030, },
+{ 0x00a7c5, CIM_LONGUPPERDELTA, -0x2543, },
+{ 0x00a7c6, CIM_LONGUPPERDELTA, -0x0a38, },
+{ 0x00a7c7, CIM_CASEBITOFF, 0x0001, },
+{ 0x00a7cb, CIM_LONGUPPERDELTA, -0x2567, },
+{ 0x00a7cc, CIM_CASEBIT, 0x0001, },
+{ 0x00a7ce, CIM_NONE, 0x0000, },
+{ 0x00a7d0, CIM_CASEBIT, 0x0001, },
+{ 0x00a7d2, CIM_NONE, 0x0000, },
+{ 0x00a7d6, CIM_CASEBIT, 0x0001, },
+{ 0x00a7dc, CIM_LONGUPPERDELTA, -0x2641, },
+{ 0x00a7dd, CIM_NONE, 0x0000, },
+{ 0x00a7f5, CIM_CASEBITOFF, 0x0001, },
+{ 0x00a7f7, CIM_NONE, 0x0000, },
 { 0x00ab53, CIM_LOWERDELTA, 0x03a0, },
 { 0x00ab54, CIM_NONE, 0x0000, },
 { 0x00ab70, CIM_LONGLOWERDELTA, 0x17d1, },
@@ -408,12 +442,43 @@
 { 0x010400, CIM_UPPERDELTA, 0x0028, },
 { 0x010428, CIM_LOWERDELTA, 0x0028, },
 { 0x010450, CIM_NONE, 0x0000, },
+{ 0x0104b0, CIM_UPPERDELTA, 0x0028, },
+{ 0x0104d4, CIM_NONE, 0x0000, },
+{ 0x0104d8, CIM_LOWERDELTA, 0x0028, },
+{ 0x0104fc, CIM_NONE, 0x0000, },
+{ 0x010570, CIM_UPPERDELTA, 0x0027, },
+{ 0x01057b, CIM_NONE, 0x0000, },
+{ 0x01057c, CIM_UPPERDELTA, 0x0027, },
+{ 0x01058b, CIM_NONE, 0x0000, },
+{ 0x01058c, CIM_UPPERDELTA, 0x0027, },
+{ 0x010593, CIM_NONE, 0x0000, },
+{ 0x010594, CIM_UPPERDELTA, 0x0027, },
+{ 0x010596, CIM_NONE, 0x0000, },
+{ 0x010597, CIM_LOWERDELTA, 0x0027, },
+{ 0x0105a2, CIM_NONE, 0x0000, },
+{ 0x0105a3, CIM_LOWERDELTA, 0x0027, },
+{ 0x0105b2, CIM_NONE, 0x0000, },
+{ 0x0105b3, CIM_LOWERDELTA, 0x0027, },
+{ 0x0105ba, CIM_NONE, 0x0000, },
+{ 0x0105bb, CIM_LOWERDELTA, 0x0027, },
+{ 0x0105bd, CIM_NONE, 0x0000, },
 { 0x010c80, CIM_CASEBIT, 0x0040, },
 { 0x010cb3, CIM_NONE, 0x0000, },
 { 0x010cc0, CIM_CASEBIT, 0x0040, },
 { 0x010cf3, CIM_NONE, 0x0000, },
+{ 0x010d50, CIM_CASEBIT, 0x0020, },
+{ 0x010d60, CIM_CASEBITOFF, 0x0020, },
+{ 0x010d66, CIM_NONE, 0x0000, },
+{ 0x010d70, CIM_CASEBIT, 0x0020, },
+{ 0x010d80, CIM_CASEBITOFF, 0x0020, },
+{ 0x010d86, CIM_NONE, 0x0000, },
 { 0x0118a0, CIM_CASEBITOFF, 0x0020, },
 { 0x0118e0, CIM_NONE, 0x0000, },
+{ 0x016e40, CIM_CASEBIT, 0x0020, },
+{ 0x016e80, CIM_NONE, 0x0000, },
+{ 0x01e900, CIM_UPPERDELTA, 0x0022, },
+{ 0x01e922, CIM_LOWERDELTA, 0x0022, },
+{ 0x01e944, CIM_NONE, 0x0000, },
 
 
 #define CASE_INFO_SHIFT0_HIGH 0x000b
