@@ -12,6 +12,7 @@
 #include "pike_error.h"
 #include "object.h"
 #include "pike_rusage.h"
+#include "pikecode.h"
 
 struct catch_context
 {
@@ -774,6 +775,10 @@ void branch_check_threads_etc(void);
 #ifdef OPCODE_INLINE_RETURN
 PIKE_OPCODE_T *inter_return_opcode_F_CATCH(PIKE_OPCODE_T *addr);
 #endif
+#ifdef OPCODE_INLINE_CATCH
+PIKE_OPCODE_T *setup_catch_context(PIKE_OPCODE_T *addr);
+PIKE_OPCODE_T *handle_caught_exception(void);
+#endif
 #ifdef PIKE_DEBUG
 void simple_debug_instr_prologue_0 (PIKE_INSTR_T instr);
 void simple_debug_instr_prologue_1 (PIKE_INSTR_T instr, INT32 arg);
