@@ -1,4 +1,4 @@
-#line 204 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 204 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0(F_UNDEFINED, "push UNDEFINED", I_UPDATE_SP)
 
 
@@ -86,7 +86,7 @@ OPCODE1(F_ARROW_STRING, "->string", I_UPDATE_SP)
 
 
 OPCODE1(F_LOOKUP_LFUN, "->lfun", 0)
-#line 317 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 317 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_LFUN, "local function", I_UPDATE_SP)
@@ -96,7 +96,7 @@ OPCODE1(F_LFUN, "local function", I_UPDATE_SP)
 
 
 OPCODE2(F_TRAMPOLINE, "trampoline", I_UPDATE_SP)
-#line 344 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 344 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -122,32 +122,32 @@ OPCODE1(F_PRIVATE_GLOBAL, "global <private>", I_UPDATE_SP)
 
 
 OPCODE2(F_PRIVATE_IF_DIRECT_GLOBAL, "global <private if direct>", I_UPDATE_SP)
-#line 387 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 387 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_ASSIGN_PRIVATE_IF_DIRECT_GLOBAL, "assign global <private if direct>", 0)
-#line 405 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 405 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_ASSIGN_PRIVATE_TYPED_GLOBAL_AND_POP, "assign global <private,typed> and pop", I_UPDATE_SP)
-#line 417 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 417 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 OPCODE2(F_ASSIGN_PRIVATE_TYPED_GLOBAL, "assign global <private,typed>", 0)
-#line 465 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 465 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE2(F_PRIVATE_TYPED_GLOBAL, "global <private,typed>", I_UPDATE_SP)
-#line 492 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 492 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 
 OPCODE2_TAIL(F_MARK_AND_EXTERNAL, "mark & external", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE2(F_EXTERNAL, "external", I_UPDATE_SP)
-#line 525 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 525 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_EXTERNAL_LVALUE, "& external", I_UPDATE_SP)
-#line 546 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 546 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_MARK_AND_LOCAL, "mark & local", I_UPDATE_SP|I_UPDATE_M_SP)
@@ -191,11 +191,11 @@ OPCODE1(F_LOCAL_LVALUE, "& local", I_UPDATE_SP)
 
 
 OPCODE2(F_LEXICAL_LOCAL, "lexical local", I_UPDATE_SP)
-#line 597 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 597 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_LEXICAL_LOCAL_LVALUE, "&lexical local", I_UPDATE_SP)
-#line 609 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 609 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_ARRAY_LVALUE, "[ lvalues ]", I_UPDATE_SP)
@@ -224,39 +224,39 @@ OPCODE1(F_CLEAR_LOCAL, "clear local", 0)
 
 
 OPCODE2(F_ADD_LOCALS_AND_POP, "local += local", 0)
-#line 680 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 680 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_ADD_LOCAL_INT_AND_POP, "local += number", 0)
-#line 698 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 698 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_ADD_LOCAL_INT, "local += number local", 0)
-#line 717 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 717 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_INC_LOCAL, "++local", I_UPDATE_SP)
-#line 733 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 733 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_POST_INC_LOCAL, "local++", I_UPDATE_SP)
-#line 749 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 749 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_INC_LOCAL_AND_POP, "++local and pop", 0)
-#line 765 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 765 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_DEC_LOCAL, "--local", I_UPDATE_SP)
-#line 781 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 781 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_POST_DEC_LOCAL, "local--", I_UPDATE_SP)
-#line 797 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 797 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_DEC_LOCAL_AND_POP, "--local and pop", 0)
-#line 813 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 813 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -264,9 +264,9 @@ OPCODE1(F_DEC_LOCAL_AND_POP, "--local and pop", 0)
 
 
 OPCODE0(F_LTOSVAL, "lvalue to svalue", I_UPDATE_SP)
-#line 850 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 850 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0(F_LTOSVAL2_AND_FREE, "ltosval2 and free", I_UPDATE_SP)
-#line 867 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 867 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -274,7 +274,7 @@ OPCODE0(F_LTOSVAL2_AND_FREE, "ltosval2 and free", I_UPDATE_SP)
 
 
 OPCODE0(F_LTOSVAL3_AND_FREE, "ltosval3 and free", I_UPDATE_SP)
-#line 898 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 898 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -282,15 +282,15 @@ OPCODE0(F_LTOSVAL3_AND_FREE, "ltosval3 and free", I_UPDATE_SP)
 
 
 OPCODE0(F_LTOSVAL_AND_FREE, "ltosval and free", I_UPDATE_SP)
-#line 920 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 920 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_ADD_TO, "+=", I_UPDATE_SP)
-#line 985 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 985 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_ADD_TO_AND_POP, "+= and pop", I_UPDATE_SP)
-#line 1048 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1048 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_GLOBAL_LVALUE, "& global", I_UPDATE_SP)
@@ -299,27 +299,27 @@ OPCODE1(F_GLOBAL_LVALUE, "& global", I_UPDATE_SP)
 
 
 OPCODE0(F_INC, "++x", I_UPDATE_SP)
-#line 1071 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1071 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_DEC, "--x", I_UPDATE_SP)
-#line 1089 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1089 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_DEC_AND_POP, "x-- and pop", I_UPDATE_SP)
-#line 1106 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1106 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_INC_AND_POP, "x++ and pop", I_UPDATE_SP)
-#line 1123 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1123 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_POST_INC, "x++", I_UPDATE_SP)
-#line 1144 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1144 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_POST_DEC, "x--", I_UPDATE_SP)
-#line 1165 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1165 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_ASSIGN_LOCAL, "assign local", 0)
@@ -395,7 +395,7 @@ OPCODE1(F_ASSIGN_GLOBAL_AND_POP, "assign global and pop", I_UPDATE_SP)
 
 
 OPCODE1(F_ASSIGN_PRIVATE_GLOBAL_AND_POP, "assign private global and pop", I_UPDATE_SP)
-#line 1249 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1249 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_ASSIGN_PRIVATE_GLOBAL, "assign private global", I_UPDATE_SP)
@@ -428,7 +428,7 @@ OPCODE1(F_POP_N_ELEMS, "pop_n_elems", I_UPDATE_SP)
 
 
 OPCODE0_TAIL(F_MARK2, "mark mark", I_UPDATE_M_SP)OPCODE0_TAIL(F_SYNCH_MARK, "synch mark", I_UPDATE_M_SP)OPCODE0(F_MARK, "mark", I_UPDATE_M_SP)
-#line 1291 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1291 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_MARK_X, "mark Pike_sp-X", I_UPDATE_M_SP)
@@ -447,7 +447,7 @@ OPCODE0(F_POP_TO_MARK, "pop to mark", I_UPDATE_SP|I_UPDATE_M_SP)
 
 
 OPCODE0_TAIL(F_CLEANUP_SYNCH_MARK, "cleanup synch mark", I_UPDATE_SP|I_UPDATE_M_SP)OPCODE0(F_POP_SYNCH_MARK, "pop synch mark", I_UPDATE_SP|I_UPDATE_M_SP)
-#line 1326 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1326 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_CLEAR_STRING_SUBTYPE, "clear string subtype", 0)
@@ -460,7 +460,7 @@ OPCODE0_BRANCH(F_BRANCH, "branch", 0)
 
 
 OPCODE2_BRANCH(F_BRANCH_IF_NOT_LOCAL_ARROW, "branch if !local->x", 0)OPCODE0_TAILBRANCH(F_BRANCH_WHEN_ZERO, "branch if zero", I_UPDATE_SP)
-#line 1357 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1357 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0_BRANCH(F_QUICK_BRANCH_WHEN_ZERO, "(Q) branch if zero", I_UPDATE_SP)
@@ -494,7 +494,7 @@ OPCODE0_BRANCH(F_BRANCH_WHEN_NON_ZERO, "branch if not zero", I_UPDATE_SP)
 
 
 OPCODE1_BRANCH(F_BRANCH_IF_TYPE_IS_NOT, "branch if type is !=", I_UPDATE_SP)
-#line 1414 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1414 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_BRANCH(F_BRANCH_IF_LOCAL, "branch if local", 0)
@@ -507,7 +507,7 @@ OPCODE1_BRANCH(F_BRANCH_IF_LOCAL, "branch if local", 0)
 
 
 OPCODE1_BRANCH(F_BRANCH_IF_NOT_LOCAL, "branch if !local", 0)
-#line 1444 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1444 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0_BRANCH(F_BRANCH_WHEN_EQ, "branch if ==", I_UPDATE_SP)
 
 OPCODE0_BRANCH(F_BRANCH_WHEN_NE, "branch if !=", I_UPDATE_SP)
@@ -561,13 +561,13 @@ OPCODE0_BRANCH(F_LOR, "||", I_UPDATE_SP)
 
 
 OPCODE0_BRANCH(F_EQ_OR, "==||", I_UPDATE_SP)
-#line 1501 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1501 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0_BRANCH(F_EQ_AND, "==&&", I_UPDATE_SP)
-#line 1522 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1522 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0_PTRJUMP(F_CATCH, "catch", I_UPDATE_ALL|I_RETURN)
-#line 1637 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1637 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_ESCAPE_CATCH, "escape catch", 0)
@@ -580,15 +580,15 @@ OPCODE0(F_EXIT_CATCH, "exit catch", I_UPDATE_SP)
 
 
 OPCODE1_JUMP(F_SWITCH, "switch", I_UPDATE_ALL)
-#line 1661 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1661 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_JUMP(F_SWITCH_ON_INDEX, "switch on index", I_UPDATE_ALL)
-#line 1680 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1680 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2_JUMP(F_SWITCH_ON_LOCAL, "switch on local", 0)
-#line 1726 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1726 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0_BRANCH(F_INC_LOOP, "++Loop", 0)
 
 OPCODE0_BRANCH(F_DEC_LOOP, "--Loop", 0)
@@ -596,13 +596,13 @@ OPCODE0_BRANCH(F_DEC_LOOP, "--Loop", 0)
 OPCODE0_BRANCH(F_INC_NEQ_LOOP, "++Loop!=", 0)
 
 OPCODE0_BRANCH(F_DEC_NEQ_LOOP, "--Loop!=", 0)
-#line 1742 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1742 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0_BRANCH(F_LOOP, "loop", I_UPDATE_SP)
-#line 1752 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1752 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0_BRANCH(F_FOREACH, "foreach", 0)
-#line 1772 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1772 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_MAKE_ITERATOR, "get_iterator", 0)
@@ -611,17 +611,17 @@ OPCODE0(F_MAKE_ITERATOR, "get_iterator", 0)
 
 
 OPCODE0_BRANCH(F_FOREACH_START, "foreach start", 0)
-#line 1790 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1790 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 OPCODE0_BRANCH(F_FOREACH_LOOP, "foreach loop", 0)
-#line 1805 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1805 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 OPCODE1_RETURN(F_RETURN_LOCAL, "return local", I_UPDATE_SP|I_UPDATE_FP)
-#line 1825 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1825 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -650,20 +650,20 @@ OPCODE0_RETURN(F_DUMB_RETURN, "dumb return", I_UPDATE_FP)
 
 
 OPCODE0(F_NEGATE, "unary minus", 0)
-#line 1872 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1872 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0_ALIAS(F_COMPL, "~", 0, o_compl)
 
 OPCODE0(F_NOT, "!", 0)
-#line 1900 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1900 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 OPCODE0_ALIAS(F_LSH, "<<", I_UPDATE_SP, o_lsh)
 
 OPCODE0_ALIAS(F_RSH, ">>", I_UPDATE_SP, o_rsh)
-#line 1913 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1913 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE0(F_EQ, "==", I_UPDATE_SP)
 
 OPCODE0(F_NE, "!=", I_UPDATE_SP)
@@ -683,12 +683,12 @@ OPCODE0(F_ADD, "+", I_UPDATE_SP)
 
 
 OPCODE0(F_ADD_INTS, "int+int", I_UPDATE_SP)
-#line 1937 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1937 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 OPCODE0(F_ADD_FLOATS, "float+float", I_UPDATE_SP)
-#line 1949 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 1949 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -752,15 +752,15 @@ OPCODE1(F_LSH_INT, "<< int", 0)
 
 
 OPCODE1(F_ADD_INT, "add integer", 0)
-#line 2015 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2015 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_ADD_NEG_INT, "add -integer", 0)
-#line 2027 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2027 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_PUSH_ARRAY, "@", I_UPDATE_SP)
-#line 2060 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2060 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_APPEND_ARRAY, "append array", I_UPDATE_SP|I_UPDATE_M_SP)
@@ -790,7 +790,7 @@ OPCODE1(F_LOCAL_INDEX, "local index", 0)
 
 
 OPCODE2(F_GLOBAL_LOCAL_INDEX, "global[local]", I_UPDATE_SP)
-#line 2098 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2098 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_LOCAL_ARROW, "local->x", I_UPDATE_SP)
@@ -804,11 +804,11 @@ OPCODE2(F_LOCAL_ARROW, "local->x", I_UPDATE_SP)
 
 
 OPCODE1(F_ARROW, "->x", 0)
-#line 2119 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2119 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_STRING_INDEX, "string index", 0)
-#line 2130 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2130 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_POS_INT_INDEX, "int index", 0)
@@ -850,7 +850,7 @@ OPCODE0_ALIAS(F_CAST_TO_INT, "cast_to_int", 0, o_cast_to_int)
 OPCODE0_ALIAS(F_CAST_TO_STRING, "cast_to_string", 0, o_cast_to_string)
 
 OPCODE0(F_SOFT_CAST, "soft cast", I_UPDATE_SP)
-#line 2187 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2187 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
@@ -865,7 +865,7 @@ OPCODE0(F_COPY_VALUE, "copy_value", 0)
 
 
 OPCODE0(F_INDIRECT, "indirect", I_UPDATE_SP)
-#line 2220 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2220 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_SIZEOF, "sizeof", 0)
@@ -889,50 +889,50 @@ OPCODE1(F_SIZEOF_LOCAL_STRING, "sizeof local string", I_UPDATE_SP)
 
 
 OPCODE2_ALIAS(F_SSCANF, "sscanf", I_UPDATE_SP, o_sscanf)
-#line 2343 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2343 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE1_JUMP(F_CALL_LFUN, "call lfun", I_UPDATE_ALL)
-#line 2357 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2357 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2_JUMP(F_CALL_LFUN_N, "call lfun <n>", I_UPDATE_ALL)
-#line 2373 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2373 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_JUMP(F_CALL_LFUN_AND_POP, "call lfun & pop", I_UPDATE_ALL)
-#line 2390 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2390 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_RETURN(F_CALL_LFUN_AND_RETURN, "call lfun & return", I_UPDATE_ALL)
-#line 2404 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2404 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_JUMP(F_MARK_CALL_LFUN, "mark, call lfun", I_UPDATE_ALL)
-#line 2416 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2416 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_JUMP(F_MARK_CALL_LFUN_AND_POP, "mark, call lfun & pop", I_UPDATE_ALL)
-#line 2432 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2432 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_RETURN(F_MARK_CALL_LFUN_AND_RETURN, "mark, call lfun & return", I_UPDATE_ALL)
-#line 2447 "/home/hww3/pike-git/src/interpret_functions.h"
-
+#line 2447 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_JUMP(F_APPLY, "apply", I_UPDATE_ALL)OPCODE1_JUMP(F_APPLY_AND_POP, "apply" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_APPLY_AND_RETURN, "apply" " & return", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_APPLY, "mark, " "apply", I_UPDATE_ALL)OPCODE1_JUMP(F_MARK_APPLY_AND_POP, "mark, " "apply" " & pop", I_UPDATE_ALL)OPCODE1_RETURN(F_MARK_APPLY_AND_RETURN, "mark, " "apply" " & return", I_UPDATE_ALL)
 
+
 OPCODE0_JUMP(F_CALL_FUNCTION, "call function", I_UPDATE_ALL)OPCODE0_JUMP(F_CALL_FUNCTION_AND_POP, "call function" " & pop", I_UPDATE_ALL)OPCODE0_RETURN(F_CALL_FUNCTION_AND_RETURN, "call function" " & return", I_UPDATE_ALL)
 
 OPCODE1_JUMP(F_CALL_OTHER, "call other", I_UPDATE_ALL)
-#line 2510 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2510 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_JUMP(F_CALL_OTHER_AND_POP, "call other & pop", I_UPDATE_ALL)
-#line 2572 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2572 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1_RETURN(F_CALL_OTHER_AND_RETURN, "call other & return", I_UPDATE_ALL)
-#line 2700 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2700 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE1(F_CALL_BUILTIN, "call builtin", I_UPDATE_ALL)
 
 
@@ -990,17 +990,19 @@ OPCODE1(F_CALL_BUILTIN1_AND_POP, "call builtin1 & pop", I_UPDATE_ALL)
 
 
 OPCODE1(F_LTOSVAL_CALL_BUILTIN_AND_ASSIGN, "ltosval, call builtin & assign", I_UPDATE_ALL)
-#line 2800 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2800 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_LTOSVAL_CALL_BUILTIN_AND_ASSIGN_POP, "ltosval, call builtin, assign & pop", I_UPDATE_ALL)
-#line 2916 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2916 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 OPCODE1_PTRJUMP(F_COND_RECUR, "recur if not overloaded", I_UPDATE_ALL)OPCODE0_TAILPTRJUMP(F_RECUR, "recur", I_UPDATE_ALL)
-#line 2967 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 2967 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 
 OPCODE0_PTRJUMP(F_RECUR_AND_POP, "recur & pop", I_UPDATE_ALL)
+#line 2970 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
+
 
 
 
@@ -1008,23 +1010,23 @@ OPCODE0_PTRJUMP(F_RECUR_AND_POP, "recur & pop", I_UPDATE_ALL)
 
 
 OPCODE0_PTRJUMP(F_TAIL_RECUR, "tail recursion", I_UPDATE_ALL)
-#line 3001 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3001 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_THIS_OBJECT, "this_object", I_UPDATE_SP)
-#line 3019 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3019 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_UNDEFINEDP, "undefinedp", 0)
-#line 3034 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3034 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_DESTRUCTEDP, "destructedp", 0)
-#line 3051 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3051 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_ZERO_TYPE, "zero_type", 0)
-#line 3068 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3068 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE0(F_SWAP, "swap", 0)
@@ -1036,7 +1038,7 @@ OPCODE0(F_DUP, "dup", I_UPDATE_SP)
 
 
 OPCODE2(F_THIS, "this", I_UPDATE_SP)
-#line 3098 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3098 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE2(F_MAGIC_TYPES, "::_types", I_UPDATE_SP)
@@ -1053,7 +1055,7 @@ OPCODE1(F_PROTECT_STACK, "protect_stack", 0)
 
 
 OPCODE2(F_FILL_STACK, "fill_stack", I_UPDATE_SP)
-#line 3122 "/home/hww3/pike-git/src/interpret_functions.h"
+#line 3122 "/home/grubba/src/Pike-Dist/src/interpret_functions.h"
 
 
 OPCODE1(F_MARK_AT, "mark_at", I_UPDATE_SP)
