@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 5cb7ac6971e85a8fbcdcfba9dd801e1a83a0c1a4 $
 */
 
 #ifndef LEX_H
@@ -23,8 +22,9 @@ struct lex
 {
   char *pos;
   char *end;
-  INT32 current_line;
+  INT_TYPE current_line;
   INT32 pragmas;
+  node *attributes;
   struct pike_string *current_file;
   int (*current_lexer)(struct lex *, YYSTYPE *);
 };
@@ -34,6 +34,7 @@ struct lex
 int parse_esc_seq0 (p_wchar0 *buf, p_wchar2 *chr, ptrdiff_t *len);
 int parse_esc_seq1 (p_wchar1 *buf, p_wchar2 *chr, ptrdiff_t *len);
 int parse_esc_seq2 (p_wchar2 *buf, p_wchar2 *chr, ptrdiff_t *len);
+int parse_esc_seq_pcharp (PCHARP buf, p_wchar2 *chr, ptrdiff_t *len);
 
 int yylex0(struct lex *, YYSTYPE *);
 int yylex1(struct lex *, YYSTYPE *);
