@@ -301,9 +301,16 @@ static struct object *low_pcx_decode( struct pike_string *data )
      switch(pcx_header.planes)
      {
       case 1:
+	if (pcx_header.bytesperline < width || b.len < 256 * 3)
+	{
+	  Pike_error("Malformed PCX Image.\n");
+	}
         load_palette_pcx( &pcx_header, &b, dest );
         break;
       case 3:
+	if (pcx_header.bytesperline < width)
+	  Pike_error("Malformed PCX Image.\n");
+
         load_rgb_pcx( &pcx_header, &b, dest );
         break;
       default:
@@ -315,9 +322,13 @@ static struct object *low_pcx_decode( struct pike_string *data )
      switch(pcx_header.planes)
      {
       case 1:
+	if (pcx_header.bytesperline <= ((width - 1) >> 3))
+	  Pike_error("Malformed PCX Image.\n");
         load_mono_pcx( &pcx_header, &b, dest );
         break;
       case 4: /* palette 16 bpl planar image!? */
+	if (pcx_header.bytesperline <= ((width - 1) >> 3))
+	  Pike_error("Malformed PCX Image.\n");
         load_planar_palette_pcx( &pcx_header, &b, dest );
         break;
       default:
