@@ -826,6 +826,13 @@ static void image_x_decode_truecolor(INT32 args)
        bshift>=bpp || bshift<0)
 	 Pike_error("Image.X.decode_truecolor: illegal colorshifts\n");
 
+   if (rbits < 0 || gbits < 0 || bbits < 0 ||
+       rbits > 24 || gbits > 24 || bbits > 24 ||
+       rbits + gbits + bbits > 24)
+   {
+	 Pike_error("Image.X.decode_truecolor: illegal colorbits\n");
+   }
+
    if (args>12)
    {
       if (TYPEOF(sp[12-args]) != T_OBJECT ||
@@ -855,13 +862,20 @@ static void image_x_decode_truecolor(INT32 args)
 	    gpos=Bpp-1-gpos,
 	    bpos=Bpp-1-bpos;
 
+      n=width*height;
+
+      if (n && ((rpos < 0 || gpos < 0 || bpos < 0) ||
+          !((size_t)rpos < len && (size_t)gpos < len && (size_t)bpos < len)))
+      {
+         Pike_error("Image.X.decode_trucolor: Malformed X image data\n");
+      }
+
       push_int(width);
       push_int(height);
       o=clone_object(image_program,2);
       img=get_storage(o,image_program);
 
       d=img->img;
-      n=width*height;
 
       if (nct)
 	 while (n--)
@@ -930,9 +944,19 @@ static void image_x_decode_truecolor(INT32 args)
       else
       {
 	 int i,j;
-	 COLORTYPE *rtbl=alloca(1<<rbits);
-	 COLORTYPE *gtbl=alloca(1<<gbits);
-	 COLORTYPE *btbl=alloca(1<<bbits);
+	 COLORTYPE *rtbl;
+	 COLORTYPE *gtbl;
+	 COLORTYPE *btbl;
+
+	 if (!(rbits && gbits && bbits))
+	   Pike_error("Image.X.decode_truecolor: illegal colorshifts\n");
+
+	 check_c_stack((1 << rbits) + (1 << gbits) + (1 << bbits));
+
+	 rtbl = alloca(1<<rbits);
+	 gtbl = alloca(1<<gbits);
+	 btbl = alloca(1<<bbits);
+
 	 if (!rtbl || !gtbl || !btbl)
 	   SIMPLE_OUT_OF_MEMORY_ERROR("decode_truecolor",
 				      (1<<rbits)+(1<<rbits)+(1<<rbits));
