@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: c66b4cb4b7199e55e2c65afde36c0b1f447a2f0e $
 */
 
 #include "global.h"
@@ -10,7 +9,7 @@
 #define SPACE_CHAR 'i'
 
 extern const unsigned char image_default_font[];
-#define IMAGE_DEFAULT_FONT_SIZE 30596
+#define IMAGE_DEFAULT_FONT_SIZE 30560
 
 
 /*! @module Image
@@ -195,12 +194,12 @@ static INLINE void free_font_struct(struct font *font)
    }
 }
 
-static void init_font_struct(struct object *o)
+static void init_font_struct(struct object *UNUSED(o))
 {
   THIS=NULL;
 }
 
-static void exit_font_struct(struct object *obj)
+static void exit_font_struct(struct object *UNUSED(obj))
 {
    free_font_struct(THIS);
    THIS=NULL;
@@ -309,10 +308,10 @@ void font_load(INT32 args)
 #ifdef HAVE_MMAP
   size_t mmaped_size = 0;
 #endif
-  size_t size = 0;
+  int size = 0;
   char *filename = NULL;
 
-  get_all_args("Image.Font->load()", args, ".%s", &filename);
+  get_all_args("load", args, ".%s", &filename);
 
   if (!filename)
   {
@@ -332,7 +331,7 @@ void font_load(INT32 args)
 
     if (fd >= 0)
     {
-      size = (size_t) file_size(fd);
+      size = file_size(fd);
       if (size > 0)
       {
 	THREADS_ALLOW();
@@ -344,7 +343,7 @@ void font_load(INT32 args)
 	else
 	{
 #endif
-	  fh = (struct file_head *)xalloc(size);
+	  fh = xalloc(size);
 #ifdef FONT_DEBUG
 	  fprintf(stderr,"FONT Malloced %p (%d)\n", fh, size);
 #endif
@@ -432,8 +431,8 @@ void font_load(INT32 args)
 
 	for (i=0; i<num_chars; i++)
 	{
-	  if (i*sizeof(INT32)<size
-	      && ntohl(fh->o[i])<size
+	  if ((i*sizeof(INT32) + OFFSETOF(file_head, o))<(size_t)size
+	      && ntohl(fh->o[i])<(size_t)size
 	      && ! ( ntohl(fh->o[i]) % 4) ) /* must be aligned */
 	  {
 	    ch = (struct char_head*)
@@ -533,16 +532,15 @@ void font_write(INT32 args)
 
    maxwidth2=1;
 
-   width_of=(int *)xalloc((args+1)*sizeof(int));
+   width_of=xalloc((args+1)*sizeof(int));
    SET_ONERROR(err, free, width_of);
 
    for (j=0; j<args; j++)
    {
       int max;
-      if (sp[j-args].type!=T_STRING)
-	 bad_arg_error("font->write",sp-args,args,0,"",sp-args,
-		"Bad arguments to font->write()\n");
-     
+      if (TYPEOF(sp[j-args]) != T_STRING)
+        SIMPLE_BAD_ARG_ERROR("write",1,"string");
+
       xsize = max = 1;
       to_write_len = sp[j-args].u.string->len;
       switch(sp[j-args].u.string->size_shift)
@@ -577,7 +575,7 @@ void font_write(INT32 args)
 	 to_write2 = STR2(sp[j-args].u.string);
 	 for (i = 0; i < to_write_len; i++)
 	 {
-	   if (to_write2[i] < (unsigned INT32)this->chars)
+	   if ((unsigned INT32)to_write2[i] < this->chars)
 	   {
 	     if (xsize+char_width(this,to_write2[i]) > max)
 	       max=xsize+char_width(this,to_write2[i]);
@@ -605,7 +603,7 @@ void font_write(INT32 args)
    else
      img->ysize = this->height;
    img->rgb.r=img->rgb.g=img->rgb.b=255;
-   img->img=malloc(img->xsize*img->ysize*sizeof(rgb_group)+1);
+   img->img=malloc(img->xsize*img->ysize*sizeof(rgb_group)+RGB_VEC_PAD);
 
    if (!img->img) {
      free_object(o);
@@ -613,7 +611,7 @@ void font_write(INT32 args)
 				img->xsize*img->ysize*sizeof(rgb_group)+1);
    }
 
-   MEMSET(img->img,0,img->xsize*img->ysize*sizeof(rgb_group));
+   memset(img->img,0,img->xsize*img->ysize*sizeof(rgb_group));
 
    for (j=0; j<args; j++)
    {
@@ -761,10 +759,9 @@ void font_text_extents(INT32 args)
      p_wchar1 *to_write1;
      p_wchar2 *to_write2;
      ptrdiff_t to_write_len;
-     if (sp[j-args].type!=T_STRING)
-	bad_arg_error("font->text_extents",sp-args,args,0,"",sp-args,
-		"Bad arguments to font->text_extents()\n");
-     
+     if (TYPEOF(sp[j-args]) != T_STRING)
+       SIMPLE_BAD_ARG_ERROR("text_extents",1,"string");
+
      xsize = max = 1;
      to_write_len = sp[j-args].u.string->len;
      switch(sp[j-args].u.string->size_shift)
