@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 1a43922f714e25848cba5f786dd3cf6008de0086 $
 */
 
 #include "global.h"
@@ -115,9 +114,9 @@ static void image_magic_index(INT32 args)
 {
    int i;
 
-   if (args!=1) 
+   if (args!=1)
       Pike_error("Image.`[]: Too few or too many arguments\n");
-   if (sp[-1].type!=T_STRING)
+   if (TYPEOF(sp[-1]) != T_STRING)
       Pike_error("Image.`[]: Illegal type of argument\n");
 
    for (i=0; i<(int)NELEM(submagic); i++)
@@ -155,7 +154,7 @@ static void image_magic_index(INT32 args)
    stack_swap();
    f_arrow(2);
 
-   if (sp[-1].type==T_INT)
+   if (TYPEOF(sp[-1]) == T_INT)
    {
       pop_stack();
       stack_dup();
@@ -164,7 +163,7 @@ static void image_magic_index(INT32 args)
       f_add(2);
       SAFE_APPLY_MASTER("resolv",1);
    }
-   if (sp[-1].type==T_INT)
+   if (TYPEOF(sp[-1]) == T_INT)
    {
       pop_stack();
       stack_dup();
@@ -183,7 +182,7 @@ static void init_cpuidflags( )
 {
   unsigned int a, b, c, d;
   char *data = alloca(20);
-  MEMSET( data, 0, 20 );
+  memset( data, 0, 20 );
 
   image_get_cpuid( 0, &a, &b, &c, &d );
 
