@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 31b2b32ae6f1b724f7bbb28853cf7985012a1bd5 $
 */
 
 /*
@@ -247,21 +246,21 @@ static void init_colorrange(rgb_group *cr,struct svalue *s,char *where)
    double fr,fg,fb,q;
    int b;
 
-   if (s->type!=T_ARRAY)
+   if (TYPEOF(*s) != T_ARRAY)
       Pike_error("Illegal colorrange to %s\n",where);
    else if (s->u.array->size<2)
       Pike_error("Colorrange array too small (meaningless) (to %s)\n",where);
 
-   vp=v=(void*)xalloc(sizeof(double)*(s->u.array->size/2+1));
-   rgbp=rgb=(void*)xalloc(sizeof(rgbd_group)*(s->u.array->size/2+1));
+   vp=v=xalloc(sizeof(double)*(s->u.array->size/2+1));
+   rgbp=rgb=xalloc(sizeof(rgbd_group)*(s->u.array->size/2+1));
 
    for (i=0; i<s->u.array->size-1; i+=2)
    {
       rgb_group rgbt;
 
-      if (s->u.array->item[i].type==T_INT) 
+      if (TYPEOF(s->u.array->item[i]) == T_INT)
 	 *vp = (double)s->u.array->item[i].u.integer;
-      else if (s->u.array->item[i].type==T_FLOAT) 
+      else if (TYPEOF(s->u.array->item[i]) == T_FLOAT)
 	 *vp = s->u.array->item[i].u.float_number;
       else 
 	 bad_arg_error(where,
@@ -323,14 +322,14 @@ static void init_colorrange(rgb_group *cr,struct svalue *s,char *where)
 
 #define GET_FLOAT_ARG(sp,args,n,def,where) \
    ( (args>n) \
-      ? ( (sp[n-args].type==T_INT) ? (double)(sp[n-args].u.integer) \
-	  : ( (sp[n-args].type==T_FLOAT) ? sp[n-args].u.float_number \
+      ? ( (TYPEOF(sp[n-args]) == T_INT) ? (double)(sp[n-args].u.integer) \
+	  : ( (TYPEOF(sp[n-args]) == T_FLOAT) ? sp[n-args].u.float_number \
 	      : ( Pike_error("illegal argument(s) to %s\n", where), 0.0 ) ) ) \
       : def )
 #define GET_INT_ARG(sp,args,n,def,where) \
    ( (args>n) \
-      ? ( (sp[n-args].type==T_INT) ? sp[n-args].u.integer \
-	  : ( (sp[n-args].type==T_FLOAT) ? DOUBLE_TO_INT(sp[n-args].u.float_number) \
+      ? ( (TYPEOF(sp[n-args]) == T_INT) ? sp[n-args].u.integer		\
+	  : ( (TYPEOF(sp[n-args]) == T_FLOAT) ? DOUBLE_TO_INT(sp[n-args].u.float_number) \
 	      : ( Pike_error("illegal argument(s) to %s\n", where), 0 ) ) ) \
       : def )
 
@@ -379,11 +378,11 @@ void image_noise(INT32 args)
    o=clone_object(image_program,0);
    img=(struct image*)o->storage;
    *img=*THIS;
-   if (!(img->img=malloc(sizeof(rgb_group)*THIS->xsize*THIS->ysize+1)))
+   if (!(img->img=malloc(sizeof(rgb_group)*THIS->xsize*THIS->ysize+RGB_VEC_PAD)))
    {
       free_object(o);
       SIMPLE_OUT_OF_MEMORY_ERROR("noise",
-				 sizeof(rgb_group)*THIS->xsize*THIS->ysize+1);
+				 sizeof(rgb_group)*THIS->xsize*THIS->ysize+RGB_VEC_PAD);
    }
 
    cscale*=COLORRANGE_LEVELS;
@@ -460,11 +459,11 @@ void image_turbulence(INT32 args)
    o=clone_object(image_program,0);
    img=(struct image*)o->storage;
    *img=*THIS;
-   if (!(img->img=malloc(sizeof(rgb_group)*THIS->xsize*THIS->ysize+1)))
+   if (!(img->img=malloc(sizeof(rgb_group)*THIS->xsize*THIS->ysize+RGB_VEC_PAD)))
    {
       free_object(o);
       SIMPLE_OUT_OF_MEMORY_ERROR("noise",
-				 sizeof(rgb_group)*THIS->xsize*THIS->ysize+1);
+				 sizeof(rgb_group)*THIS->xsize*THIS->ysize+RGB_VEC_PAD);
    }
 
    cscale*=COLORRANGE_LEVELS;
@@ -532,7 +531,7 @@ void image_random(INT32 args)
    push_int(THIS->xsize);
    push_int(THIS->ysize);
    o=clone_object(image_program,2);
-   img=(struct image*)get_storage(o,image_program);
+   img=get_storage(o,image_program);
    d=img->img;
    if (args) f_random_seed(args);
 
@@ -562,7 +561,7 @@ void image_randomgrey(INT32 args)
    push_int(THIS->xsize);
    push_int(THIS->ysize);
    o=clone_object(image_program,2);
-   img=(struct image*)get_storage(o,image_program);
+   img=get_storage(o,image_program);
    d=img->img;
    if (args) f_random_seed(args);
 
