@@ -15,7 +15,6 @@
 #include "mapping.h"
 #include "stralloc.h"
 #include "program_id.h"
-#include "block_alloc.h"
 #include <ctype.h>
 
 #include "parser.h"
@@ -63,10 +62,8 @@ static int m_isidchar2( unsigned int x )
     a = *_a = resize_array( a, a->malloced_size + 10 );			\
     a->size = sz;							\
   }									\
-  a->item[sz].type = PIKE_T_STRING;					\
-  a->item[sz].subtype = 0;						\
-  a->item[sz].u.string =						\
-    PIKE_CONCAT(make_shared_binary_string,X)(x, l);			\
+  SET_SVAL(a->item[sz], PIKE_T_STRING, 0, string,			\
+	   PIKE_CONCAT(make_shared_binary_string,X)(x, l));		\
   a->size++;								\
 }
 
@@ -170,12 +167,12 @@ static void f_tokenize( INT32 args )
 /*! @endmodule
  */
 
-void init_parser_c()
+void init_parser_c(void)
 {
   ADD_FUNCTION2("tokenize", f_tokenize,
 		tFunc(tStr, tArr(tOr(tArr(tStr),tStr))), 0, 0);
 }
 
-void exit_parser_c()
+void exit_parser_c(void)
 {
 }
