@@ -11,9 +11,6 @@
 @TOP@
 @BOTTOM@
 
-/* Define if we are running PostgreSQL 7.2 or newer */
-#undef HAVE_PG72
-
 /* Define if postgres passed sanity tests. */
 #undef HAVE_WORKING_POSTGRES
 
@@ -48,23 +45,7 @@
 
 /* Time to include stuff. */
 
-/* postgres_fe.h should be used in preference to postgres.h in
- * client code.
- */
 #include "override.h"
-#ifdef HAVE_POSTGRESQL_SERVER_POSTGRES_FE_H
-#include <server/postgres_fe.h>
-#elif defined(HAVE_SERVER_POSTGRES_FE_H)
-#include <server/postgres_fe.h>
-#elif defined(HAVE_POSTGRES_FE_H)
-#include <postgres_fe.h>
-#elif defined(HAVE_POSTGRESQL_SERVER_POSTGRES_H)
-#include <server/postgres.h>
-#elif defined(HAVE_SERVER_POSTGRES_H)
-#include <server/postgres.h>
-#elif defined(HAVE_POSTGRES_H)
-#include <postgres.h>
-#endif /* HAVE_POSTGRES_FE_H */
 #include <libpq-fe.h>
 
 #endif
