@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 37f66d3210802a497586766f97455aec42362b72 $
 */
 
 /*
@@ -68,7 +67,7 @@ PIKE_MUTEX_T pike_postgres_mutex STATIC_MUTEX_INIT;
 #ifdef PGDEBUG
 #define pgdebug printf
 #else
-static void pgdebug (char * a, ...) {}
+static void pgdebug (char * UNUSED(a), ...) {}
 #endif
 
 struct program * postgres_program;
@@ -82,7 +81,7 @@ static void set_error (char * newerror)
 	return;
 }
 
-static void pgres_create (struct object * o) {
+static void pgres_create (struct object * UNUSED(o)) {
 	pgdebug ("pgres_create().\n");
 	THIS->dblink=NULL;
 	THIS->last_error=NULL;
@@ -97,7 +96,7 @@ static void pgres_create (struct object * o) {
 
 }
 
-static void pgres_destroy (struct object * o)
+static void pgres_destroy (struct object * UNUSED(o))
 {
 	PGconn * conn;
 	PQ_FETCH();
@@ -115,7 +114,7 @@ static void pgres_destroy (struct object * o)
 			free_string(THIS->last_error);
 		THIS->last_error=NULL;
 	}
-	if (THIS->notify_callback.type!=PIKE_T_FREE) {
+	if (TYPEOF(THIS->notify_callback) != PIKE_T_FREE) {
 		free_svalue(&THIS->notify_callback);
 		mark_free_svalue(&THIS->notify_callback);
 	}
@@ -128,13 +127,16 @@ static void pgres_destroy (struct object * o)
  *!
  *! @class postgres
  *!
- *! This is an interface to the Postgres database server using libpq.
- *! This module may or may not be available on your Pike, depending
- *! whether the appropriate include and library files 
+ *! This is an interface to the Postgres (Postgres95, PostgreSQL)
+ *! database server using libpq.
+ *!
+ *! This module may or may not be available on your Pike, depending on
+ *! whether or not the appropriate include and library files
  *! could be found at compile-time. Note that you @b{do not@}
  *! need to have a Postgres server running on your host to use this module:
  *! you can connect to the database over a TCP/IP socket.
  *!
+ *! @note
  *! Please notice that unless you wish to specifically connect to a Postgres
  *! server, you'd better use the @[Sql.Sql], which is a server-independent
  *! sql-server-class. The interfaces to all existing sql-classes
@@ -165,22 +167,44 @@ static void pgres_destroy (struct object * o)
  *! @string
  *!   @value "PGHOST"
  *!     Sets the name of the default host to connect to. It defaults
- *! 	to "localhost"
+ *! 	to @expr{"localhost"@}.
+ *!   @value "PGHOSTADDR"
+ *!     Set the numeric IP address to connect to.  This may be set instead of
+ *!     or in addition to PGHOST to avoid DNS lookups.
+ *!   @value "PGPORT"
+ *!     Sets the default port or unix domain socket file extension to connect to,
+ *!     otherwise it will use compile-time defaults (that is: the time you compiled
+ *!     the postgres library, not the Pike driver).
+ *!   @value "PGDATABASE"
+ *!     Sets the default database to connect to.
+ *!   @value "PGUSER"
+ *!     Sets the default username used to connect to the database.
+ *!   @value "PGPASSWORD"
+ *!     Set the default password used to connect to the database.  This is not
+ *!     recommended for security reasons, some operating systems allow non-root
+ *!     users to see process environment variables.  Use your ~/.pgpass file instead.
+ *!   @value "PGSERVICE"
+ *!     Sets the service name to be looked up in pg_service.conf.  This is a
+ *!     shorter way to set all the parameters.
+ *!   @value "PGSSLMODE"
+ *!     This determines how SSL connections will be negotiated.  If set to @b{disable@},
+ *!     it will require an unencrypted connection; @b{allow@} will negotiate a non-SSL
+ *!     connection, and if it fails try an SSL connection; @b{prefer@} will attempt SSL
+ *!     connections first, falling back to non-SSL if SSL fails; and @b{require@} will
+ *!     force an SSL connection or cause an error if SSL is not available.
  *!   @value "PGOPTIONS"
  *!     Sets some extra flags for the frontend-backend connection.
- *!     DO NOT SET unless you're sure of what you're doing.
- *!   @value "PGPORT"
- *!     Sets the default port to connect to, otherwise it will use
- *!     compile-time defaults (that is: the time you compiled the postgres
- *! 	library, not the Pike driver).
+ *!     @b{do not set@} unless you're sure of what you're doing.
+ *!   @value "PGREALM"
+ *!     Sets the Kerberos realm for authentication, if it is different
+ *!     from the local realm.  PostgreSQL will attempt to authenticate
+ *!     with servers for this realm and use seperate ticket files to avoid
+ *!     conflicts with local ticket files.  This variable is only used if
+ *!     Keberos authentication is selected in PostgreSQL.
  *!   @value "PGTTY"
  *!     Sets the file to be used for Postgres frontend debugging.
  *!     Do not use, unless you're sure of what you're doing.
- *!   @value "PGDATABASE"
- *!     Sets the default database to connect to.
- *!   @value "PGREALM"
- *!     Sets the default realm for Kerberos authentication. I never used
- *!   	this, so I can't help you.
+ *!     This variable is ignored in recent versions of PostgreSQL.
  *! @endstring
  *!
  *! Refer to the libpq documentation for further details.
@@ -213,9 +237,7 @@ static void pgres_destroy (struct object * o)
  *! will try to connect to the default database.
  *!
  *! @note
- *! You need to have a database selected before using the sql-object, 
- *! otherwise you'll get exceptions when you try to query it.
- *! Also notice that this function @b{can@} raise exceptions if the db
+ *! Notice that this function @b{can@} raise exceptions if the db
  *! server doesn't respond, if the database doesn't exist or is not accessible
  *! by you.
  *!
@@ -238,7 +260,7 @@ static void f_create (INT32 args)
 	PGconn * conn;
 	PQ_FETCH();
 
-	get_all_args("postgres->create",args,
+	get_all_args("create",args,
 		     ".%s%s%s%s%d%G",
 		     &host,
 		     &db,
@@ -308,11 +330,11 @@ static void f_create (INT32 args)
 
 static void f_select_db (INT32 args)
 {
-	char *host, *port, *options, *tty, *db;
+	char *host, *port, *options, *db;
 	PGconn * conn, *newconn;
 	PQ_FETCH();
 
-	get_all_args("Postgres->select_db",args,"%s", &db);
+	get_all_args("select_db",args,"%s", &db);
 	
 	if (!THIS->dblink)
 	  Pike_error ("Driver error. How can you possibly not be linked to a "
@@ -332,7 +354,7 @@ static void f_select_db (INT32 args)
 	host=PQhost(conn);
 	port=PQport(conn);
 	options=PQoptions(conn);
-	tty=PQtty(conn);
+
 	/* This could be really done calling f_create, but it's more efficient this
 	 * way */
 	/* using newconn is necessary or otherwise the datastructures I use
@@ -340,7 +362,7 @@ static void f_select_db (INT32 args)
 	 * situations (i.e. if the temporary use of _one_ more filedescriptor
 	 * is not possible.
 	 */
-	newconn=PQsetdb(host,port,options,tty,db);
+	newconn=PQsetdb(host,port,options,NULL,db);
 	PQfinish(conn);
 	conn=newconn;
 	PQ_UNLOCK();
@@ -410,7 +432,7 @@ static void f_big_query(INT32 args)
         switch(args)
         {
           default:
-            if(Pike_sp[1-args].type == PIKE_T_ARRAY)
+            if(TYPEOF(Pike_sp[1-args]) == PIKE_T_ARRAY)
               bnds=Pike_sp[1-args].u.array;
       
           case 1:
@@ -431,7 +453,7 @@ static void f_big_query(INT32 args)
 
 	  for (i=0,item=bnds->item; cnt--; item++,i++) {
 	    int sendbin=0;
-	    switch(item->type)
+	    switch(TYPEOF(*item))
 	    { case PIKE_T_STRING: {
 	          long len;
 		  const char*p;
@@ -459,7 +481,7 @@ static void f_big_query(INT32 args)
 	        break;
 	      default:
                   Pike_error("Expected string or UNDEFINED element, Got %d.\n",
-		   item->type);
+		   TYPEOF(*item));
 	        break;
 	    }
 	    paramFormats[i] = sendbin;
@@ -607,12 +629,12 @@ yupbegin:       res=PQexec(conn,"BEGIN");
 			pgdebug("\tBad.\n");
 			set_error(PQerrorMessage(conn));
 			PQclear(res);
-			Pike_error ("Error in frontend-backend communications.\n");
+			Pike_error("Postgres error: %S\n", THIS->last_error);
 		case PGRES_TUPLES_OK:
 			pgdebug("\tResult.\n");
 			THIS->last_result=res;
                         THIS->last_rows=PQntuples(res);
-			push_object(this_object());
+			ref_push_object(this_object());
 			push_object(clone_object(pgresult_program,1));
 			return;
 		default:
@@ -684,7 +706,7 @@ static void f_trace (INT32 args)
 {
 	if (args!=1)
 		Pike_error ("Wrong args for trace().\n");
-	if (Pike_sp[-args].type==PIKE_T_INT)
+	if (TYPEOF(Pike_sp[-args]) == PIKE_T_INT)
 		if (Pike_sp[-args].u.integer==0)
 			PQuntrace(THIS->dblink);
 		else
@@ -731,8 +753,8 @@ static void f_callback(INT32 args)
 	check_all_args("postgres->_set_notify_callback()",
 		       args, BIT_INT|BIT_FUNCTION, 0);
 
-	if (Pike_sp[-args].type==PIKE_T_INT) {
-		if (THIS->notify_callback.type!=PIKE_T_FREE) {
+	if (TYPEOF(Pike_sp[-args]) == PIKE_T_INT) {
+		if (TYPEOF(THIS->notify_callback) != PIKE_T_FREE) {
 			free_svalue(&THIS->notify_callback);
 			mark_free_svalue (&THIS->notify_callback);
 		}
@@ -797,7 +819,7 @@ static void f_quote(INT32 args)
 	struct pike_string *s;
 	char *err_msg;
 
-	get_all_args("Postgres->_quote", args, "%S", &s);
+	get_all_args("_quote", args, "%S", &s);
 
 	ret = begin_shared_string(s->len * 2 + 1);
 #ifdef HAVE_PQESCAPESTRINGCONN
