@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 32cd92e18bd1bea59f20301419718aff172d658b $
 */
 
 #ifndef CHARSETMOD_H
@@ -11,10 +10,6 @@
 #include "global.h"
 #include "stralloc.h"
 
-static void DECLSPEC(noreturn) transcode_error_va (
-  struct pike_string *str, ptrdiff_t pos, struct pike_string *charset,
-  int encode, const char *reason, va_list args) ATTRIBUTE((noreturn));
-
 void DECLSPEC(noreturn) transcode_error (
   struct pike_string *str, ptrdiff_t pos, struct pike_string *charset,
   int encode, const char *reason, ...);
@@ -75,6 +70,7 @@ extern const UNICHAR map_ANSI_X3_4_1968[];
 extern const UNICHAR map_ISO_8859_1_1998[];
 extern const UNICHAR map_JIS_C6226_1983[];
 extern const UNICHAR * const iso2022_94[];
+extern const UNICHAR * const iso2022_94_2[];
 extern const UNICHAR * const iso2022_96[];
 extern const UNICHAR * const iso2022_9494[];
 extern const UNICHAR * const iso2022_9696[];
