@@ -1713,7 +1713,7 @@ fprintf(stderr,"_gif_decode_lzw(%lx,%lu,%d,%lx,%lx,%lx,%lu,%d)\n",
       if (debug) fprintf(stderr,"code=%d 0x%02x bits=%d\n",n,n,bits);
 #endif
 
-      if (n==m && last!=n) 
+      if (n==m && last!=n && last!=clearcode)
       {
 	// Copy the last color from the previous sequence
 	 c[n].prev=last;
@@ -1922,6 +1922,12 @@ void image_gif__decode(INT32 args)
 			"array has illegal contents "
 			"(illegal type(s) in block array in position %d)\n",i);
 
+               if (b->item[7].u.integer > 12 || b->item[7].u.integer < 2)
+                  Pike_error("Image.GIF._decode: given (__decode'd) "
+                             "array has illegal contents "
+                             "(illegal bit count in block array in position %d)\n",
+                             i);
+
 	       push_int(GIF_RENDER);
 
 	       push_svalue(b->item+1);
