@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: eae07377f0a3c4cc288129325c98b276f6f9380b $
 */
 
 #include "global.h"
@@ -126,17 +125,17 @@ void f_parse_accessed_database(INT32 args)
   if(!args)
     SIMPLE_TOO_FEW_ARGS_ERROR("parse_accessed_database",1);
 
-  if ((sp[-args].type != T_STRING) || (sp[-args].u.string->size_shift)) {
+  if ((TYPEOF(sp[-args]) != T_STRING) || (sp[-args].u.string->size_shift)) {
     Pike_error("Bad argument 1 to parse_accessed_database(string(0..255)).\n");
   }
 
   /* Pop all but the first argument */
   pop_n_elems(args-1);
 
-  push_constant_text("\n");
+  push_text("\n");
   f_divide(2);
 
-  if (sp[-1].type != T_ARRAY) {
+  if (TYPEOF(sp[-1]) != T_ARRAY) {
     Pike_error("Expected array as result of string-division.\n");
   }
 
@@ -183,9 +182,9 @@ void f_parse_html(INT32 args)
   ONERROR serr, cerr, eerr, sserr;
 
   if (args<3||
-      sp[-args].type!=T_STRING||
-      sp[1-args].type!=T_MAPPING||
-      sp[2-args].type!=T_MAPPING)
+      TYPEOF(sp[-args]) != T_STRING||
+      TYPEOF(sp[1-args]) != T_MAPPING||
+      TYPEOF(sp[2-args]) != T_MAPPING)
     Pike_error("Bad argument(s) to parse_html.\n");
 
   ss=sp[-args].u.string;
@@ -250,9 +249,9 @@ void f_parse_html_lines(INT32 args)
   struct array *extra_args;
   ONERROR serr, cerr, eerr, sserr;
   if (args<3||
-      sp[-args].type!=T_STRING||
-      sp[1-args].type!=T_MAPPING||
-      sp[2-args].type!=T_MAPPING)
+      TYPEOF(sp[-args]) != T_STRING||
+      TYPEOF(sp[1-args]) != T_MAPPING||
+      TYPEOF(sp[2-args]) != T_MAPPING)
     Pike_error("Bad argument(s) to parse_html_lines.\n");
 
   ss=sp[-args].u.string;
@@ -310,7 +309,7 @@ static char end_quote_character = '\000';
  */
 void f_set_end_quote(INT32 args)
 {
-  if(args < 1 || sp[-1].type != T_INT)
+  if(args < 1 || TYPEOF(sp[-1]) != T_INT)
     Pike_error("Wrong argument to set_end_quote(int CHAR)\n");
   end_quote_character = (char) sp[-1].u.integer;
 }
@@ -319,7 +318,7 @@ void f_set_end_quote(INT32 args)
  */
 void f_set_start_quote(INT32 args)
 {
-  if(args < 1 || sp[-1].type != T_INT)
+  if(args < 1 || TYPEOF(sp[-1]) != T_INT)
     Pike_error("Wrong argument to set_start_quote(int CHAR)\n");
   start_quote_character = (char) sp[-1].u.integer;
 }
@@ -416,7 +415,7 @@ ptrdiff_t push_parsed_tag(char *s, ptrdiff_t len)
   int is_SSI_tag;
 
   /* NOTE: At entry sp[-1] is the tagname */
-  is_SSI_tag = (sp[-1].type == T_STRING) &&
+  is_SSI_tag = (TYPEOF(sp[-1]) == T_STRING) &&
     (!strncmp(sp[-1].u.string->str, "!--", 3));
 
   /* Find X=Y pairs. */
@@ -449,7 +448,7 @@ ptrdiff_t push_parsed_tag(char *s, ptrdiff_t len)
   return i;
 }
 
-INLINE int tagsequal(char *s, char *t, ptrdiff_t len, char *end)
+static INLINE int tagsequal(char *s, char *t, ptrdiff_t len, char *end)
 {
   if(s+len >= end)  return 0;
 
@@ -550,14 +549,14 @@ void do_html_parse(struct pike_string *ss,
 
       push_string(make_shared_binary_string((char *)s+n, j-n));
       f_lower_case(1);
-      add_ref(sval2.u.string = sp[-1].u.string);
-      sval2.type=T_STRING;
+      add_ref(sp[-1].u.string);
+      SET_SVAL(sval2, T_STRING, 0, string, sp[-1].u.string);
       pop_stack();
 
       /* Is this a non-container? */
       mapping_index_no_free(&sval1,single,&sval2);
 
-      if (sval1.type==T_STRING)
+      if (TYPEOF(sval1) == T_STRING)
       {
 	int quote = 0;
 	/* A simple string ... */
@@ -590,7 +589,7 @@ void do_html_parse(struct pike_string *ss,
 	i=last=j;
 	continue;
       }
-      else if (sval1.type!=T_INT)
+      else if (TYPEOF(sval1) != T_INT)
       {
 	ONERROR sv1, sv2;
 	/* Hopefully something callable ... */
@@ -610,7 +609,7 @@ void do_html_parse(struct pike_string *ss,
 	free_svalue(&sval2);
 	free_svalue(&sval1);
 
-	if (sp[-1].type==T_STRING)
+	if (TYPEOF(sp[-1]) == T_STRING)
 	{
 	  copy_shared_string(ss2,sp[-1].u.string);
 	  pop_stack();
@@ -622,7 +621,7 @@ void do_html_parse(struct pike_string *ss,
 	  i=last=j+k;
 	  do_html_parse(ss2,cont,single,strings,recurse_left-1,extra_args);
 	  continue;
-	} else if (sp[-1].type==T_ARRAY) {
+	} else if (TYPEOF(sp[-1]) == T_ARRAY) {
 	  push_empty_string();
 	  f_multiply(2);
 	  copy_shared_string(ss2,sp[-1].u.string);
@@ -646,7 +645,7 @@ void do_html_parse(struct pike_string *ss,
       /* Is it a container then? */
       free_svalue(&sval1);
       mapping_index_no_free(&sval1,cont,&sval2);
-      if (sval1.type==T_STRING)
+      if (TYPEOF(sval1) == T_STRING)
       {
 	if (last < i-1)
 	{
@@ -664,7 +663,7 @@ void do_html_parse(struct pike_string *ss,
 	i=last=j;
 	continue;
       }
-      else if (sval1.type != T_INT)
+      else if (TYPEOF(sval1) != T_INT)
       {
 	ONERROR sv1, sv2;
 	assign_svalue_no_free(sp++, &sval2);
@@ -689,7 +688,7 @@ void do_html_parse(struct pike_string *ss,
 	free_svalue(&sval1);
 	free_svalue(&sval2);
 
-	if (sp[-1].type==T_STRING)
+	if (TYPEOF(sp[-1]) == T_STRING)
 	{
 	  copy_shared_string(ss2,sp[-1].u.string);
 	  pop_stack();
@@ -705,7 +704,7 @@ void do_html_parse(struct pike_string *ss,
 	  do_html_parse(ss2,cont,single,strings,recurse_left-1,extra_args);
 	  continue;
 
-	} else if (sp[-1].type==T_ARRAY) {
+	} else if (TYPEOF(sp[-1]) == T_ARRAY) {
 	  push_empty_string();
 	  f_multiply(2);
 	  copy_shared_string(ss2,sp[-1].u.string);
@@ -783,11 +782,11 @@ void do_html_parse(struct pike_string *ss,
 
 #define HANDLE_RETURN_VALUE(END) do {		\
   free_svalue(&sval1);                          \
-  if (sp[-1].type==T_STRING)			\
+  if (TYPEOF(sp[-1]) == T_STRING)		\
   {						\
     PARSE_RECURSE(END);				\
     continue;					\
-  } else if (sp[-1].type==T_ARRAY) {		\
+  } else if (TYPEOF(sp[-1]) == T_ARRAY) {	\
     PARSE_RETURN(END);				\
     continue;					\
   }						\
@@ -842,16 +841,16 @@ void do_html_parse_lines(struct pike_string *ss,
 
       push_string(make_shared_binary_string((char *)s+i, j-i));
       f_lower_case(1);
-      add_ref(sval2.u.string = sp[-1].u.string);
-      sval2.type=T_STRING;
+      add_ref(sp[-1].u.string);
+      SET_SVAL(sval2, T_STRING, 0, string, sp[-1].u.string);
       pop_stack();
 
       /* Is this a non-container? */
       mapping_index_no_free(&sval1,single,&sval2);
-/*       if(sval1.type == T_INT) */
+/*       if(TYPEOF(sval1) == T_INT) */
 /* 	mapping_index_no_free(&sval1,single,&empty_string_svalue); */
 
-      if (sval1.type==T_STRING)
+      if (TYPEOF(sval1) == T_STRING)
       {
 	int quote = 0;
 	/* A simple string ... */
@@ -886,7 +885,7 @@ void do_html_parse_lines(struct pike_string *ss,
 	i=last=j;
 	continue;
       }
-      else if (sval1.type!=T_INT)
+      else if (TYPEOF(sval1) != T_INT)
       {
 	ONERROR sv1;
 	*(sp++)=sval2;
@@ -913,9 +912,9 @@ void do_html_parse_lines(struct pike_string *ss,
       /* Is it a container then? */
 
       mapping_index_no_free(&sval1,cont,&sval2);
-      if(sval1.type == T_INT)
+      if(TYPEOF(sval1) == T_INT)
 	mapping_index_no_free(&sval1,cont,&empty_string_svalue);
-      if (sval1.type==T_STRING)
+      if (TYPEOF(sval1) == T_STRING)
       {
 	if (last < i-1)
 	{
@@ -935,7 +934,7 @@ void do_html_parse_lines(struct pike_string *ss,
 	i=last=j;
 	continue;
       }
-      else if (sval1.type != T_INT)
+      else if (TYPEOF(sval1) != T_INT)
       {
 	ONERROR sv1;
 
@@ -987,31 +986,6 @@ void do_html_parse_lines(struct pike_string *ss,
   }
 }
 
-/*! @decl array(int) get_all_active_fds()
- */
-void f_get_all_active_fd(INT32 args)
-{
-  int i,fds,ne;
-  PIKE_STAT_T foo;
-
-  ne = MAX_OPEN_FILEDESCRIPTORS;
-
-  pop_n_elems(args);
-  for (i=fds=0; i<ne; i++)
-  {
-    int q;
-    THREADS_ALLOW();
-    q = fd_fstat(i,&foo);
-    THREADS_DISALLOW();
-    if(!q)
-    {
-      push_int(i);
-      fds++;
-    }
-  }
-  f_aggregate(fds);
-}
-
 /*! @decl string fd_info(int fd)
  */
 void f_fd_info(INT32 args)
@@ -1023,7 +997,7 @@ void f_fd_info(INT32 args)
   VALID_FILE_IO("spider.fd_info","status");
 
   if (args<1||
-      sp[-args].type!=T_INT)
+      TYPEOF(sp[-args]) != T_INT)
     Pike_error("Illegal argument to fd_info\n");
   i=sp[-args].u.integer;
   pop_n_elems(args);
@@ -1043,10 +1017,10 @@ void f_fd_info(INT32 args)
 static void program_name(struct program *p)
 {
   char *f;
-  INT32 n=0;
+  INT_TYPE n=0;
   ref_push_program(p);
   APPLY_MASTER("program_name", 1);
-  if(sp[-1].type == T_STRING)
+  if(TYPEOF(sp[-1]) == T_STRING)
     return;
   pop_stack();
   f=(char *)(p->linenumbers+1);
@@ -1106,27 +1080,27 @@ PIKE_MODULE_INIT
   pop_stack();
 
   ADD_FUNCTION("_low_program_name",f__low_program_name,
-	       tFunc(tPrg(tObj),tStr),0);
+	       tDeprecated(tFunc(tPrg(tObj),tStr)),0);
 
   /* function(int:int) */
   ADD_FUNCTION("set_start_quote",f_set_start_quote,
-	       tFunc(tInt,tInt),OPT_EXTERNAL_DEPEND);
+	       tDeprecated(tFunc(tInt,tInt)),OPT_EXTERNAL_DEPEND);
 
   /* function(int:int) */
   ADD_FUNCTION("set_end_quote",f_set_end_quote,
-	   tFunc(tInt,tInt),OPT_EXTERNAL_DEPEND);
+               tDeprecated(tFunc(tInt,tInt)),OPT_EXTERNAL_DEPEND);
 
   /* function(string:array) */
   ADD_FUNCTION("parse_accessed_database", f_parse_accessed_database,
-	       tFunc(tStr,tArray), OPT_TRY_OPTIMIZE);
+	       tDeprecated(tFunc(tStr,tArray)), OPT_TRY_OPTIMIZE);
 
   /* function(:array(array)) */
   ADD_FUNCTION("_dump_obj_table", f__dump_obj_table,
-	       tFunc(tNone,tArr(tArray)), OPT_EXTERNAL_DEPEND);
+	       tDeprecated(tFunc(tNone,tArr(tArray))), OPT_EXTERNAL_DEPEND);
 
 
   ADD_FUNCTION("parse_html",f_parse_html,
-	   tFuncV(tStr
+               tDeprecated(tFuncV(tStr
 		  tMap(tStr,tOr(tStr,
 				tFuncV(tOr(tStr,tVoid)
 				       tOr(tMap(tStr,tStr),tVoid),
@@ -1139,12 +1113,12 @@ PIKE_MODULE_INIT
 				       tMix,
 				       tOr(tStr,tArr(tStr))))),
 		  tMix,
-		  tStr),
+                  tStr)),
 	   OPT_SIDE_EFFECT);
 
 
   ADD_FUNCTION("parse_html_lines",f_parse_html_lines,
-	   tFuncV(tStr
+               tDeprecated(tFuncV(tStr
 		  tMap(tStr,tOr(tStr,
 				tFuncV(tOr(tStr,tVoid)
 				       tOr(tMap(tStr,tStr),tVoid)
@@ -1159,21 +1133,18 @@ PIKE_MODULE_INIT
 				       tMix,
 				       tOr(tStr,tArr(tStr))))),
 		  tMix,
-		  tStr),
+                  tStr)),
 	   0);
 
   /* function(int:array) */
-  ADD_FUNCTION("discdate", f_discdate,tFunc(tInt,tArray), 0);
+  ADD_FUNCTION("discdate", f_discdate, tDeprecated(tFunc(tInt,tArray)), 0);
 
   /* function(int,void|int:int) */
-  ADD_FUNCTION("stardate", f_stardate,tFunc(tInt tInt,tInt), 0);
-
-  /* function(:array(int)) */
-  ADD_FUNCTION("get_all_active_fd", f_get_all_active_fd,
-	       tFunc(tNone,tArr(tInt)), OPT_EXTERNAL_DEPEND);
+  ADD_FUNCTION("stardate", f_stardate, tDeprecated(tFunc(tInt tInt,tInt)), 0);
 
   /* function(int:string) */
-  ADD_FUNCTION("fd_info", f_fd_info,tFunc(tInt,tStr), OPT_EXTERNAL_DEPEND);
+  ADD_FUNCTION("fd_info", f_fd_info, tDeprecated(tFunc(tInt,tStr)),
+               OPT_EXTERNAL_DEPEND);
 }
 
 
