@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 9bede919c5025e21fe1a31bf455dee0fed23f9ed $
 */
 
 /*
@@ -41,7 +40,6 @@
 #include "module_support.h"
 #include "builtin_functions.h"
 #include "dmalloc.h"
-#include "port.h"
 #include "multiset.h"
 #include "mapping.h"
 
@@ -261,7 +259,7 @@ static int handle_errors (pike_sybase_connection *this) {
     show_severity(severity);
   }
 
-  MEMCPY(this->error,message.sqlerrm.sqlerrmc,
+  memcpy(this->error,message.sqlerrm.sqlerrmc,
          message.sqlerrm.sqlerrml+1);
 
   this->had_error=1;
@@ -416,17 +414,17 @@ static void f_connect (INT32 args) {
                  BIT_INT|BIT_VOID,0);
 
   /* fetch arguments, so that we can enable threads */
-  if (sp[2-args].type == T_STRING && sp[2-args].u.string->len) { /*username*/
+  if (TYPEOF(sp[2-args]) == T_STRING && sp[2-args].u.string->len) { /*username*/
     username=sp[2-args].u.string->str;
     usernamelen=sp[2-args].u.string->len;
     sybdebug((stderr,"\tgot username: %s\n",username));
   }
-  if (sp[3-args].type == T_STRING && sp[2-args].u.string->len) { /*password*/
+  if (TYPEOF(sp[3-args]) == T_STRING && sp[2-args].u.string->len) { /*password*/
       pass=sp[3-args].u.string->str;
     passlen=sp[3-args].u.string->len;
     sybdebug((stderr,"\tgot password: %s\n",pass));
   }
-  if (sp[-args].type==T_STRING && sp[-args].u.string->len) { /*hostname*/
+  if (TYPEOF(sp[-args]) == T_STRING && sp[-args].u.string->len) { /*hostname*/
     hostname=sp[-args].u.string->str;
     hostnamelen=sp[-args].u.string->len;
     sybdebug((stderr,"\tgot hostname: %s\n",hostname));
@@ -742,9 +740,9 @@ static void f_big_query(INT32 args) {
       sybdebug((stderr,"I have %d columns' worth of data\n",numcols));
       sybdebug((stderr,"Allocating results**\n"));
       /* it looks like xalloc can't be used here. Hubbe? */
-      results=(char**)malloc(numcols*sizeof(char*));
-      results_lengths=(CS_INT*)malloc(numcols*sizeof(CS_INT));
-      nulls=(CS_SMALLINT*)malloc(numcols*sizeof(CS_SMALLINT));
+      results=malloc(numcols*sizeof(char*));
+      results_lengths=malloc(numcols*sizeof(CS_INT));
+      nulls=malloc(numcols*sizeof(CS_SMALLINT));
       this->results=results;
       this->results_lengths=results_lengths;
       this->nulls=nulls;
@@ -766,8 +764,8 @@ static void f_big_query(INT32 args) {
         sybdebug((stderr,"Allocating %ld+%d+1 bytes\n",
                  length,EXTRA_COLUMN_SPACE));
         /* it looks like xalloc can't be used here. Hubbe? */
-        results[j]=(char*)malloc((length+EXTRA_COLUMN_SPACE+1)*
-                                 sizeof(char));
+        results[j]=malloc((length+EXTRA_COLUMN_SPACE+1)*
+                          sizeof(char));
         if (results[j]==NULL) {
           sybdebug((stderr,"PANIC! COULDN'T ALLOCATE MEMORY!"));
         }
@@ -800,8 +798,8 @@ static void f_big_query(INT32 args) {
         length=guess_column_length(cmd,1);
 
         sybdebug((stderr,"Guessed length of %d\n",length));
-        function_result=(char*)malloc((length+EXTRA_COLUMN_SPACE+1)*
-                                         sizeof(char));
+        function_result=malloc((length+EXTRA_COLUMN_SPACE+1)*
+                               sizeof(char));
 
         description.datatype=CS_CHAR_TYPE;
         description.format=CS_FMT_NULLTERM;
@@ -1083,7 +1081,7 @@ static void f_fetch_fields(INT32 args) {
     push_text("name");
     push_text(desc->name);
     sybdebug((stderr,"name is %s\n",desc->name));
-    push_text("type");
+    ref_push_string(literal_type_string);
     switch(desc->datatype) {
       desc_type(CS_ILLEGAL_TYPE,illegal);
       desc_type(CS_CHAR_TYPE,char);
