@@ -43,6 +43,7 @@
 #include "pike_rusage.h"
 #include "pike_netlib.h"
 #include "pike_cpulib.h"
+#include "fdlib.h"
 
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
@@ -115,8 +116,19 @@
 #include <sys/loadavg.h>
 #endif
 
-#include "dmalloc.h"
+#ifdef HAVE_SYS_CLONEFILE_H
+#include <sys/clonefile.h>
+#endif
 
+#ifdef HAVE_LINUX_FS_H
+#include <linux/fs.h>
+#endif
+
+#ifdef HAVE_SYS_IOCTL_H
+#include <sys/ioctl.h>
+#endif
+
+#include "dmalloc.h"
 
 #define sp Pike_sp
 
@@ -242,7 +254,7 @@ static void report_error(const char *function_name)
  *!   This function is not available on all platforms.
  *!
  *! @seealso
- *!   @[symlink()], @[mv()], @[rm()]
+ *!   @[symlink()], @[clonefile()], @[mv()], @[rm()]
  */
 void f_hardlink(INT32 args)
 {
@@ -278,7 +290,7 @@ void f_hardlink(INT32 args)
  *!   This function is not available on all platforms.
  *!
  *! @seealso
- *!   @[hardlink()], @[readlink()], @[mv()], @[rm()]
+ *!   @[hardlink()], @[readlink()], @[clonefile()], @[mv()], @[rm()]
  */
 void f_symlink(INT32 args)
 {
@@ -433,6 +445,85 @@ void f_resolvepath(INT32 args)
 }
 #endif /* HAVE_RESOLVEPATH || HAVE_REALPATH */
 
+#if !defined(HAVE_CLONEFILE) && defined(HAVE_COPY_FILE_RANGE)
+int clonefile(const char *from, const char *to, int flags)
+{
+  int ret = -1;
+  int fromfd = -1;
+  int tofd = -1;
+  struct stat stat;
+
+  if (flags) {
+    /* No flags are supported currently. */
+    errno = EINVAL;
+    return -1;
+  }
+
+  fromfd = fd_open(from, fd_RDONLY, 0);
+  if (fromfd < 0) return -1;
+
+  if (fd_fstat(fromfd, &stat) < 0) goto cleanup;
+
+  if ((stat.st_mode & S_IFMT) != S_IFREG) {
+    errno = EINVAL;
+    goto cleanup;
+  }
+
+  tofd = fd_open(to, fd_CREAT|fd_TRUNC|fd_RDWR, stat.st_mode);
+  if (tofd < 0) goto cleanup;
+
+  ret = copy_file_range(fromfd, NULL, tofd, NULL, stat.st_size, 0);
+
+ cleanup:
+  if (tofd >= 0) close(tofd);
+
+  if (fromfd >= 0) close(fromfd);
+
+  return ret;
+}
+
+#define HAVE_CLONEFILE
+#endif
+
+#ifdef HAVE_CLONEFILE
+/*! @decl void clonefile(string from, string to)
+ *!
+ *! Copy a file @[from] with copy-on-write semantics to the destination named
+ *! @[to].
+ *!
+ *! @note
+ *!   This function is currently only available on macOS and Linux, and then
+ *!   only when @[from] and @[to] reference a common file system with
+ *!   copy-on-write support (e.g. an APFS volume).
+ *!
+ *! @seealso
+ *!   @[hardlink()], @[symlink()]
+ */
+void f_clonefile(INT32 args)
+{
+  char *from;
+  char *to;
+  int err;
+
+  VALID_FILE_IO("clonefile","write");
+
+  get_all_args("clonefile",args, "%s%s", &from, &to);
+
+  do {
+    THREADS_ALLOW_UID();
+    err = clonefile(from, to, 0);
+    THREADS_DISALLOW_UID();
+    if (err >= 0 || errno != EINTR) break;
+    check_threads_etc();
+  } while (1);
+
+  if (err < 0) {
+    report_error("clonefile");
+  }
+  pop_n_elems(args);
+}
+#endif /* HAVE_CLONEFILE */
+
 /*! @decl int umask(void|int mask)
  *!
  *! Set the current umask to @[mask].
@@ -709,17 +800,21 @@ static void sync(void)
       HANDLE volfile;
 
       if (QueryDosDeviceA(driveletter, device, MAX_PATH*2)) {
-	volfile = CreateFileA(device, FILE_READ_DATA, FILE_SHARE_READ,
+        volfile = CreateFileA(device, GENERIC_WRITE|GENERIC_READ,
+                              FILE_SHARE_WRITE|FILE_SHARE_READ,
 			      NULL, OPEN_EXISTING, 0, NULL);
 	if (volfile != INVALID_HANDLE_VALUE) {
+          FlushFileBuffers(volfile);
 	  CloseHandle(volfile);
 	}
       }
 
       /* Flush the drive. */
-      volfile = CreateFileA(drive, FILE_READ_DATA, FILE_SHARE_READ,
+      volfile = CreateFileA(drive, GENERIC_WRITE|GENERIC_READ,
+                            FILE_SHARE_WRITE|FILE_SHARE_READ,
 			    NULL, OPEN_EXISTING, 0, NULL);
       if (volfile != INVALID_HANDLE_VALUE) {
+        FlushFileBuffers(volfile);
 	CloseHandle(volfile);
       }
     }
@@ -3193,6 +3288,11 @@ PIKE_MODULE_INIT
   ADD_FUNCTION2("resolvepath", f_resolvepath,tFunc(tStr,tStr), 0, OPT_EXTERNAL_DEPEND);
 #endif /* HAVE_RESOLVEPATH || HAVE_REALPATH */
 
+#ifdef HAVE_CLONEFILE
+/* function(string, string:void) */
+  ADD_FUNCTION2("clonefile", f_clonefile,tFunc(tStr tStr,tVoid), 0, OPT_SIDE_EFFECT);
+#endif /* HAVE_CLONEFILE */
+
   /* function(int|void:int) */
   ADD_EFUN("umask", f_umask, tFunc(tOr(tInt,tVoid),tInt), OPT_SIDE_EFFECT);
   ADD_FUNCTION2("umask", f_umask, tFunc(tOr(tInt,tVoid),tInt), 0, OPT_SIDE_EFFECT);
