@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 4d4f801768f9bf1156cba014fc617ff34d5c297c $
 */
 
 #ifndef OPCODES_H
@@ -50,6 +49,8 @@ struct keyword
 #define I_UPDATE_FP	512	/* Opcode modifies Pike_fp */
 #define I_UPDATE_M_SP	1024	/* Opcode modifies Pike_mark_sp */
 
+#define I_RETURN	2048	/* Opcode may return to the previous frame. */
+
 /* Convenience variants */
 #define I_TWO_ARGS	(I_HASARG | I_HASARG2)
 #define I_DATA		(I_HASARG | I__DATA)
@@ -92,8 +93,10 @@ struct instr
 #ifdef PIKE_DEBUG
   long compiles;
 #endif
-  int flags;
+#ifdef PIKE_DEBUG
   const char *name;
+#endif
+  int flags;
 #ifdef PIKE_USE_MACHINE_CODE
   void *address;
 #endif
@@ -220,7 +223,6 @@ enum Pike_opcodes
   F_DO,
   F_EFUN_CALL,
   F_FOR,
-  F_IDENTIFIER,
   F_LSH_EQ,
   F_LVALUE_LIST,
   F_MOD_EQ,
@@ -252,6 +254,10 @@ enum Pike_opcodes
   /* Alias for F_RETURN, but cannot be optimized into a tail recursion call */
   F_VOLATILE_RETURN,
 
+  /* Alias for F_ASSIGN, used when LHS has side-effects that should
+   * only be evaluated once. */
+  F_ASSIGN_SELF,
+
   F_MAX_INSTR,
 };
 
@@ -289,6 +295,7 @@ enum Pike_opcodes
 #undef OPCODE1_ALIAS
 #undef OPCODE2_ALIAS
 
+#ifdef PIKE_DEBUG
 const char *low_get_f_name(int n,struct program *p);
 const char *get_f_name(int n);
 #ifdef HAVE_COMPUTED_GOTO
@@ -297,6 +304,7 @@ const char *get_opcode_name(PIKE_INSTR_T n);
 #define get_opcode_name(n) get_f_name(n + F_OFFSET)
 #endif /* HAVE_COMPUTED_GOTO */
 const char *get_token_name(int n);
+#endif
 void init_opcodes(void);
 void exit_opcodes(void);
 
