@@ -381,13 +381,15 @@ INT32 assemble(int store_linenumbers)
 	  {
 	    case TWOO(F_LOR,F_BRANCH_WHEN_NON_ZERO):
 	      c[e].opcode=F_BRANCH_WHEN_NON_ZERO;
-	    case TWOO(F_LOR,F_LOR):
+              /* FALLTHRU */
+            case TWOO(F_LOR,F_LOR):
 	      c[e].arg=c[tmp].arg;
 	      continue;
 	      
 	    case TWOO(F_LAND,F_BRANCH_WHEN_ZERO):
 	      c[e].opcode=F_BRANCH_WHEN_ZERO;
-	    case TWOO(F_LAND,F_LAND):
+              /* FALLTHRU */
+            case TWOO(F_LAND,F_LAND):
 	      c[e].arg=c[tmp].arg;
 	      continue;
 	      
@@ -527,9 +529,13 @@ INT32 assemble(int store_linenumbers)
 
     switch(c->opcode)
     {
+    case F_START_FUNCTION:
+#ifdef INS_START_FUNCTION
+      INS_START_FUNCTION();
+#endif
+      break;
     case F_NOP:
     case F_NOTREACHED:
-    case F_START_FUNCTION:
       break;
     case F_ALIGN:
       ins_align(c->arg);
@@ -639,8 +645,8 @@ INT32 assemble(int store_linenumbers)
 	}
 #endif /* INS_F_JUMP_WITH_TWO_ARGS */
 
-	/* FALL_THROUGH
-	 *
+        /* FALLTHRU */
+        /*
 	 * Note that the pointer in this case will be handled by the
 	 * next turn through the loop.
 	 */
@@ -670,8 +676,8 @@ INT32 assemble(int store_linenumbers)
 	}
 #endif /* INS_F_JUMP_WITH_ARG */
 
-	/* FALL_THROUGH
-	 *
+        /* FALLTHRU */
+        /*
 	 * Note that the pointer in this case will be handled by the
 	 * next turn through the loop.
 	 */
