@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 0d4c9ba12461c120b9c2a48d5031d5ea39ff0ab8 $
 */
 
 #ifndef PIKE_COMPILER_H
@@ -34,9 +33,10 @@ struct compilation
 
   int compilation_depth;		/* Current class nesting depth. */
 
-  int saved_threads_disabled;
-  struct mapping *resolve_cache_save;
-
+#ifdef PIKE_THREADS
+  int saved_lock_depth;
+#endif
+  struct mapping *resolve_cache;
 };
 
 #ifdef PIKE_DEBUG
