@@ -1,6 +1,4 @@
 /* Misc stuff for dealing with floats.
- *
- * $Id: d36dd32f59c8cb35bdead29df0c2abeaf88553fb $
  */
 
 #ifndef PIKE_FLOAT_H
@@ -35,7 +33,7 @@
 #define PIKE_ISNAN(X)	_isnan(X)
 #else /* !HAVE__ISNAN */
 /* Fallback function */
-static INLINE int pike_isnan(double x)
+static INLINE int ATTRIBUTE((unused)) pike_isnan(double x)
 {
   return ((x == 0.0) == (x < 0.0)) &&
     ((x == 0.0) == (x > 0.0));
