@@ -429,24 +429,6 @@ PMOD_EXPORT void *debug_xcalloc(size_t n, size_t s)
   return 0;
 }
 
-PMOD_EXPORT void *xalloc_aligned(size_t size, size_t alignment) {
-    void * ret;
-
-    if (!size) return 0;
-
-#ifdef HAVE_POSIX_MEMALIGN
-    if (posix_memalign(&ret, alignment, size)) {
-	Pike_error(msg_out_of_mem_2, size);
-    }
-#else
-    if ((ret = memalign(alignment, size)) == NULL) {
-	Pike_error(msg_out_of_mem_2, size);
-    }
-#endif
-
-    return ret;
-}
-
 PMOD_EXPORT char *debug_xstrdup(const char *src)
 {
   char *dst = NULL;
@@ -1100,7 +1082,7 @@ static MUTEX_T debug_malloc_mutex;
 #undef ENCAPSULATE_MALLOC
 #define calloc    dlcalloc
 #define free	  dlfree
-#define malloc	  dlmalloc
+#define malloc(x) dlmalloc(x)
 #define memalign  dlmemalign
 #define realloc	  dlrealloc
 #define valloc	  dlvalloc
@@ -1384,7 +1366,7 @@ void *fake_calloc(size_t x, size_t y)
 #define fake_calloc calloc
 #define fake_realloc realloc
 #else
-#define malloc fake_malloc
+#define malloc(x) fake_malloc(x)
 #define free fake_free
 #define realloc fake_realloc
 #define calloc fake_calloc
@@ -1394,7 +1376,7 @@ void *fake_calloc(size_t x, size_t y)
 /* Don't understand what this is supposed to do, but it won't work
  * with USE_DL_MALLOC. /mast */
 #ifdef WRAP
-#define malloc __real_malloc
+#define malloc(x) __real_malloc(x)
 #define free __real_free
 #define realloc __real_realloc
 #define calloc __real_calloc
