@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 10f7180fe9e3acdcb7b2ac0e64dfd08ac692e47c $
 */
 
 #ifndef SECURITY_H
@@ -90,14 +89,14 @@ struct pike_creds
     if(!CHECK_SECURITY(SECURITY_BIT_CONDITIONAL_IO))			\
       Pike_error(name ": Permission denied.\n");	       		\
 									\
-    push_constant_text(name);						\
-    push_constant_text(access_type);					\
+    push_text(name);						\
+    push_text(access_type);					\
 									\
     for(e=0;e<args;e++) push_svalue(base_sp+e);				\
 									\
     safe_apply(OBJ2CREDS(CURRENT_CREDS)->user,"valid_io",args+2);	\
 									\
-    switch(Pike_sp[-1].type)				       		\
+    switch(TYPEOF(Pike_sp[-1]))						\
     {									\
       case PIKE_T_ARRAY:				       		\
       case PIKE_T_OBJECT:				       		\
