@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 6e75ad94b6dc37894c6768da96adf5f55a779e1c $
 */
 
 /*
@@ -26,6 +25,7 @@
 #include <string.h>
 #include <nettle/md5.h>
 
+#include "pike_memory.h"
 #include "nettle.h"
 
 static const unsigned char itoa64[] =	/* 0 ... 63 => ascii - 64 */
@@ -39,14 +39,9 @@ static const unsigned char itoa64[] =	/* 0 ... 63 => ascii - 64 */
 
 
 char *pike_crypt_md5(int pl, const char *const pw,
-		     int sl, const char *const salt)
+		     int sl, const char *const salt,
+                     int ml, const char *const magic)
 {
-  static const char *const magic = "$1$"; /*
-			       * This string is magic for
-			       * this algorithm.  Having
-			       * it this way, we can get
-			       * better later on
-			       */
   static char passwd[23], *p;
   unsigned char final[MD5_DIGEST_SIZE];
   int i;
@@ -66,7 +61,7 @@ char *pike_crypt_md5(int pl, const char *const pw,
   /* Generate second hash */
   /* ctx is now reset by md5_digest */
   md5_update(&ctx, pl, (uint8_t *) pw);
-  md5_update(&ctx, strlen(magic), (uint8_t *) magic);
+  md5_update(&ctx, ml, (uint8_t *) magic);
   md5_update(&ctx, sl, (uint8_t *) salt);
 
   /* Take as many charaters from first hash as there are
@@ -114,11 +109,11 @@ char *pike_crypt_md5(int pl, const char *const pw,
   TO64(4, 10, 5);
   l = final[11];
   *p++ = itoa64[ l & 0x3f ];
-  *p++ = itoa64[ (l>>=6) & 0x3f ];
+  *p++ = itoa64[ (l>>6) & 0x3f ];
   *p = '\0';
 
   /* Clear some memory */
-  memset(final, 0, sizeof(final) );
+  guaranteed_memset(final, 0, sizeof(final) );
 
   return passwd;
 }
