@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: e531a0d1e8353eda3646bcd59a15d694de3e0536 $
 */
 
 #include "global.h"
@@ -88,7 +87,7 @@ static struct data get_data( struct source *src, off_t len )
       }
       len -= s->skip;
       buffer = malloc( len );
-      MEMCPY( buffer, s->str->str+s->skip, len);
+      memcpy( buffer, s->str->str+s->skip, len);
     }
     else
     {
@@ -101,7 +100,7 @@ static struct data get_data( struct source *src, off_t len )
 	  s->s.eof = 1;
       }
       buffer = malloc( len );
-      MEMCPY( buffer, s->str->str, len );
+      memcpy( buffer, s->str->str, len );
     }
     res.data = buffer;
     res.len = len;
@@ -137,7 +136,7 @@ static void f_got_data( INT32 args )
   remove_callbacks( (struct source *)s );
 
   if( s->str ||
-      Pike_sp[-1].type != PIKE_T_STRING ||
+      TYPEOF(Pike_sp[-1]) != PIKE_T_STRING ||
       Pike_sp[-1].u.string->size_shift ||
       Pike_sp[-1].u.string->len == 0)
   {
@@ -167,12 +166,12 @@ struct source *source_pikestream_make( struct svalue *s,
 {
   struct pf_source *res;
 
-  if( (s->type != PIKE_T_OBJECT) ||
+  if( (TYPEOF(*s) != PIKE_T_OBJECT) ||
       (find_identifier("set_read_callback",s->u.object->prog)==-1) )
     return 0;
   
-  res = malloc( sizeof( struct pf_source ) );
-  MEMSET( res, 0, sizeof( struct pf_source ) );
+  res = calloc( 1, sizeof( struct pf_source ) );
+  if( !res ) return NULL;
 
   res->len = len;
   res->skip = start;
