@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 769de1ef140af3268e4d5d61819cb93b82b50e0e $
 */
 
 /* An implementation of a threaded red/black balanced binary tree.
@@ -16,7 +15,6 @@
 #include "pike_error.h"
 #include "rbtree_low.h"
 
-#include <assert.h>
 #include <stdlib.h>
 
 #if defined (PIKE_DEBUG) || defined (TEST_MULTISET)
@@ -36,7 +34,7 @@ DECLSPEC(noreturn) static void debug_custom_rb_fatal (
 
 #endif
 
-void rbstack_push (struct rbstack_ptr *rbstack, struct rb_node_hdr *node)
+void rbstack_low_push (struct rbstack_ptr *rbstack, struct rb_node_hdr *node)
 {
   struct rbstack_slice *new = ALLOC_STRUCT (rbstack_slice);
   new->up = rbstack->slice;
@@ -50,7 +48,7 @@ void rbstack_push (struct rbstack_ptr *rbstack, struct rb_node_hdr *node)
   rbstack->ssp = 1;
 }
 
-void rbstack_pop (struct rbstack_ptr *rbstack)
+void rbstack_low_pop (struct rbstack_ptr *rbstack)
 {
   struct rbstack_slice *old = rbstack->slice;
   rbstack->slice = old->up;
@@ -61,20 +59,20 @@ void rbstack_pop (struct rbstack_ptr *rbstack)
   rbstack->ssp = STACK_SLICE_SIZE;
 }
 
-void rbstack_up (struct rbstack_ptr *rbstack)
+void rbstack_low_up (struct rbstack_ptr *rbstack)
 {
   rbstack->slice = rbstack->slice->up;
   rbstack->ssp = STACK_SLICE_SIZE;
 }
 
-void rbstack_up_to_root (struct rbstack_ptr *rbstack)
+void rbstack_low_up_to_root (struct rbstack_ptr *rbstack)
 {
   struct rbstack_slice *up;
   while ((up = rbstack->slice->up)) rbstack->slice = up;
   rbstack->ssp = 0;
 }
 
-void rbstack_free (struct rbstack_ptr *rbstack)
+void rbstack_low_free (struct rbstack_ptr *rbstack)
 {
   struct rbstack_slice *ptr = rbstack->slice;
   do {
@@ -89,6 +87,11 @@ void rbstack_free (struct rbstack_ptr *rbstack)
   rbstack->ssp = 0;
 }
 
+void rbstack_do_free (struct rbstack_ptr *rbstack_ptr)
+{
+  RBSTACK_FREE (*rbstack_ptr);
+}
+
 /* Inserts the given node at *pos and advances *pos. *top is the top
  * of the stack, which also is advanced to keep track of the top. */
 void rbstack_insert (struct rbstack_ptr *top, struct rbstack_ptr *pos,
@@ -102,7 +105,7 @@ void rbstack_insert (struct rbstack_ptr *top, struct rbstack_ptr *pos,
     rbp2.slice->stack[--rbp2.ssp] = rbp1.slice->stack[--rbp1.ssp];
     if (!rbp2.ssp) rbp2.slice = rbp1.slice, rbp2.ssp = STACK_SLICE_SIZE;
     if (!rbp1.ssp) {
-      if (rbp1.slice->up) rbstack_up (&rbp1);
+      if (rbp1.slice->up) rbstack_low_up (&rbp1);
 #ifdef PIKE_DEBUG
       else if (rbp1.ssp != rbpos.ssp || rbp1.slice != rbpos.slice)
 	Pike_fatal ("Didn't find the given position on the stack.\n");
@@ -114,86 +117,6 @@ void rbstack_insert (struct rbstack_ptr *top, struct rbstack_ptr *pos,
   *pos = rbp2;
 }
 
-#if 0
-/* Disabled since these aren't tested and not currently used. */
-
-void rbstack_assign (struct rbstack_ptr *target, struct rbstack_ptr *source)
-{
-  struct rbstack_slice *src_slice = source->slice;
-  struct rbstack_slice *tgt_slice = target->slice;
-
-#ifdef PIKE_DEBUG
-  if (target->ssp) Pike_fatal ("target rbstack not empty.\n");
-#endif
-
-  target->ssp = source->ssp;
-  source->ssp = 0;
-
-  if (src_slice->up) {
-    struct rbstack_slice *prev_slice;
-    target->slice = src_slice;
-    do {
-      prev_slice = src_slice;
-      src_slice = src_slice->up;
-    } while (src_slice->up);
-    MEMCPY ((char *) &tgt_slice->stack, (char *) &src_slice->stack,
-	    STACK_SLICE_SIZE * sizeof (struct rb_node_hdr *));
-    prev_slice->up = tgt_slice;
-    source->slice = src_slice;
-  }
-  else {
-    MEMCPY ((char *) &tgt_slice->stack, (char *) &src_slice->stack,
-	    target->ssp * sizeof (struct rb_node_hdr *));
-#ifdef RB_STATS
-    tgt_slice->maxdepth = src_slice->maxdepth;
-    tgt_slice->depth = src_slice->depth;
-#endif
-  }
-}
-
-void rbstack_copy (struct rbstack_ptr *target, struct rbstack_ptr *source)
-{
-  struct rbstack_slice *src_slice = source->slice;
-  struct rbstack_slice *tgt_stack_slice = target->slice;
-  size_t ssp = source->ssp;
-
-#ifdef PIKE_DEBUG
-  if (target->ssp) Pike_fatal ("target rbstack not empty.\n");
-#endif
-
-  target->ssp = ssp;
-
-  if (src_slice->up) {
-    struct rbstack_slice *tgt_slice =
-      target->slice = ALLOC_STRUCT (rbstack_slice);
-#ifdef RB_STATS
-    rbstack_slice_allocs++;
-#endif
-    MEMCPY ((char *) &tgt_slice->stack, (char *) &src_slice->stack,
-	    ssp * sizeof (struct rb_node_hdr *));
-    ssp = STACK_SLICE_SIZE;
-    while ((src_slice = src_slice->up)->up) {
-      tgt_slice->up = ALLOC_STRUCT (rbstack_slice);
-      tgt_slice = tgt_slice->up;
-#ifdef RB_STATS
-      rbstack_slice_allocs++;
-#endif
-      MEMCPY ((char *) &tgt_slice->stack, (char *) &src_slice->stack,
-	      STACK_SLICE_SIZE * sizeof (struct rb_node_hdr *));
-    }
-    tgt_slice->up = tgt_stack_slice;
-  }
-
-  MEMCPY ((char *) &tgt_stack_slice->stack, (char *) &src_slice->stack,
-	  ssp * sizeof (struct rb_node_hdr *));
-
-#ifdef RB_STATS
-  target->slice->maxdepth = target->slice->depth = source->slice->depth;
-#endif
-}
-
-#endif	/* Not tested or used. */
-
 /* Offsets all the rb_node_hdr pointers in rbstack from their offsets
  * relative oldbase to the same relative newbase. Useful if the memory
  * block containing the tree has been moved. */
@@ -905,7 +828,7 @@ struct rb_node_hdr *low_rb_unlink_with_move (struct rb_node_hdr **root,
     }
 
     keep_flags (node,
-		MEMCPY ((char *) node + OFFSETOF (rb_node_hdr, flags),
+		memcpy ((char *) node + OFFSETOF (rb_node_hdr, flags),
 			(char *) unlink + OFFSETOF (rb_node_hdr, flags),
 			node_size - OFFSETOF (rb_node_hdr, flags)));
 
@@ -952,25 +875,6 @@ struct rb_node_hdr *low_rb_unlink_with_move (struct rb_node_hdr **root,
   return unlink;
 }
 
-#if 0
-struct rb_node_hdr *low_rb_unlink_with_move (struct rb_node_hdr **root,
-					     struct rbstack_ptr *rbstack_ptr,
-					     int keep_rbstack,
-					     size_t node_size)
-{
-  struct rb_node_hdr *node = RBSTACK_PEEK (*rbstack_ptr), *next = rb_next (node);
-  struct rb_node_hdr *unlink =
-    real_low_rb_unlink_with_move (root, rbstack_ptr, 1, node_size);
-  debug_check_rbstack (*root, *rbstack_ptr);
-  if (node != unlink) next = node;
-  if (RBSTACK_PEEK (*rbstack_ptr) != next)
-    Pike_fatal ("Stack got %p on top, but next node is %p.\n",
-		RBSTACK_PEEK (*rbstack_ptr), next);
-  if (!keep_rbstack) RBSTACK_FREE (*rbstack_ptr);
-  return unlink;
-}
-#endif
-
 /* Like low_rb_unlink_with_move, but relinks the nodes instead of
  * moving over the data. Somewhat slower unless the size of the nodes
  * is large. */
@@ -1048,21 +952,6 @@ void low_rb_unlink_without_move (struct rb_node_hdr **root,
   *rbstack_ptr = rbstack;
 }
 
-#if 0
-void low_rb_unlink_without_move (struct rb_node_hdr **root,
-				 struct rbstack_ptr *rbstack_ptr,
-				 int keep_rbstack)
-{
-  struct rb_node_hdr *node = RBSTACK_PEEK (*rbstack_ptr), *next = rb_next (node);
-  real_low_rb_unlink_without_move (root, rbstack_ptr, 1);
-  debug_check_rbstack (*root, *rbstack_ptr);
-  if (RBSTACK_PEEK (*rbstack_ptr) != next)
-    Pike_fatal ("Stack got %p on top, but next node is %p.\n",
-		RBSTACK_PEEK (*rbstack_ptr), next);
-  if (!keep_rbstack) RBSTACK_FREE (*rbstack_ptr);
-}
-#endif
-
 /* Constructs a stack from the given root down to the given node. The
  * stack is constructed at *rbstack_ptr, and it's updated so that the
  * node is on its top on return. The given root must be the root of
@@ -1278,10 +1167,6 @@ void rb_remove_node (struct rb_node_hdr **root,
   RBSTACK_INIT (rbstack);
 #ifdef PIKE_DEBUG
   if (!node) Pike_fatal ("Tree is empty.\n");
-#if 0
-  if (find_fn (key, to_delete))
-    Pike_fatal ("Given key doesn't match the node to delete.\n");
-#endif
 #endif
   LOW_RB_TRACK_NEQ (rbstack, node, cmp_res = find_fn (key, node) >= 0 ? 1 : -1, ;, ;);
   while (node != to_delete) {
@@ -1332,10 +1217,6 @@ struct rb_node_hdr *rb_remove_node_with_move (struct rb_node_hdr **root,
   RBSTACK_INIT (rbstack);
 #ifdef PIKE_DEBUG
   if (!node) Pike_fatal ("Tree is empty.\n");
-#if 0
-  if (find_fn (key, to_delete))
-    Pike_fatal ("Given key doesn't match the node to delete.\n");
-#endif
 #endif
   LOW_RB_TRACK_NEQ (rbstack, node, cmp_res = find_fn (key, node) >= 0 ? 1 : -1, ;, ;);
   while (node != to_delete) {
@@ -1738,7 +1619,7 @@ size_t rbstack_slice_allocs = 0;
 size_t rb_num_adds = 0, rb_add_rebalance_cnt = 0;
 size_t rb_num_deletes = 0, rb_del_rebalance_cnt = 0;
 
-void reset_rb_stats()
+void reset_rb_stats(void)
 {
   rb_num_sidesteps = rb_num_sidestep_ops = 0;
   rb_num_finds = rb_find_depth = 0;
@@ -1907,7 +1788,7 @@ static void debug_rb_fatal (struct rb_node_hdr *tree, const char *fmt, ...)
 {
   va_list args;
   va_start (args, fmt);
-  (void) VFPRINTF (stderr, fmt, args);
+  (void) vfprintf (stderr, fmt, args);
   fputs ("Dumping tree:\n", stderr);
   debug_dump_rb_tree (tree, NULL, NULL);
   debug_fatal ("\r");
@@ -1918,7 +1799,7 @@ static void debug_custom_rb_fatal (struct rb_node_hdr *tree, dump_data_fn *dump_
 {
   va_list args;
   va_start (args, fmt);
-  (void) VFPRINTF (stderr, fmt, args);
+  (void) vfprintf (stderr, fmt, args);
   fputs ("Dumping tree:\n", stderr);
   debug_dump_rb_tree (tree, dump_data, extra);
   debug_fatal ("\r");
