@@ -14,6 +14,10 @@ struct sigdesc;
 void my_signal(int sig, sigfunctype fun);
 PMOD_EXPORT void check_signals(struct callback *foo, void *bar, void *gazonk);
 void set_default_signal_handler(int signum, void (*func)(INT32));
+#ifdef __NT__
+struct pid_status *pid_status_unlink_pty(struct pid_status *pid);
+int check_pty_clients(struct my_pty *pty);
+#endif
 void process_started(pid_t pid);
 void process_done(pid_t pid, const char *from);
 struct wait_data;
