@@ -2,7 +2,6 @@
 || This file is part of Pike. For copyright information see COPYRIGHT.
 || Pike is distributed under GPL, LGPL and MPL. See the file COPYING
 || for more information.
-|| $Id: 8d445d8ffd19d2f4e09e2e5062abc02b988c13a2 $
 */
 
 #ifndef TIME_STUFF_H
@@ -78,4 +77,28 @@ struct timeval
 };
 #endif
 
+PMOD_EXPORT extern struct timeval current_time;
+PMOD_EXPORT extern int current_time_invalid;
+
+#define INVALIDATE_CURRENT_TIME() do { current_time_invalid = 1; } while (0)
+#define UPDATE_CURRENT_TIME() do {					\
+	    GETTIMEOFDAY(&current_time);				\
+	    current_time_invalid = 0;					\
+	} while (0)
+#define ACCURATE_GETTIMEOFDAY(X) do {					\
+	    UPDATE_CURRENT_TIME();					\
+	    *(X) = current_time;					\
+	} while (0)
+#define ACCURATE_GETTIMEOFDAY_RVAL(X, ___rval) do {			\
+	    (___rval) = GETTIMEOFDAY(&current_time);			\
+	    current_time_invalid = 0;					\
+	    *(X) = current_time;					\
+	} while (0)
+#define INACCURATE_GETTIMEOFDAY(X) do {					\
+	    /* unlikely() not available */				\
+	    if (!(current_time_invalid)) { }				\
+	    else UPDATE_CURRENT_TIME();					\
+	    *(X) = current_time;					\
+	} while (0)
+
 #endif
